@@ -17,7 +17,6 @@ Common Auth Middleware.
 """
 
 from oslo_log import log as logging
-from oslo_log import versionutils
 from oslo_serialization import jsonutils
 import webob.dec
 import webob.exc
@@ -41,28 +40,9 @@ def _load_pipeline(loader, pipeline):
     return app
 
 
-def pipeline_factory(loader, global_conf, **local_conf):
-    """A paste pipeline replica that keys off of auth_strategy."""
-    versionutils.report_deprecated_feature(
-        LOG,
-        "The legacy V2 API code tree has been removed in Newton. "
-        "Please remove legacy v2 API entry from api-paste.ini, and use "
-        "V2.1 API or V2.1 API compat mode instead"
-    )
-
-
 def pipeline_factory_v21(loader, global_conf, **local_conf):
     """A paste pipeline replica that keys off of auth_strategy."""
-    auth_strategy = CONF.api.auth_strategy
-    if auth_strategy == 'noauth2':
-        versionutils.report_deprecated_feature(
-            LOG,
-            "'[api]auth_strategy=noauth2' is deprecated as of the 21.0.0 "
-            "Ussuri release and will be removed in a future release. Please "
-            "remove any 'noauth2' entries from api-paste.ini; only the "
-            "'keystone' pipeline is supported."
-        )
-    return _load_pipeline(loader, local_conf[auth_strategy].split())
+    return _load_pipeline(loader, local_conf['keystone'].split())
 
 
 class InjectContext(wsgi.Middleware):
@@ -93,8 +73,6 @@ class NovaKeystoneContext(wsgi.Middleware):
     def __call__(self, req):
         # Build a context, including the auth_token...
         remote_address = req.remote_addr
-        if CONF.api.use_forwarded_for:
-            remote_address = req.headers.get('X-Forwarded-For', remote_address)
 
         service_catalog = None
         if req.headers.get('X_SERVICE_CATALOG') is not None:
