@@ -24,7 +24,6 @@ from oslo_log import log as logging
 from oslo_serialization import base64
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
 
 from nova.api.metadata import password
 from nova.api.metadata import vendordata_dynamic
@@ -72,6 +71,7 @@ NEWTON_TWO = '2016-10-06'
 OCATA = '2017-02-22'
 ROCKY = '2018-08-27'
 VICTORIA = '2020-10-14'
+EPOXY = '2025-04-04'
 
 OPENSTACK_VERSIONS = [
     FOLSOM,
@@ -83,6 +83,7 @@ OPENSTACK_VERSIONS = [
     OCATA,
     ROCKY,
     VICTORIA,
+    EPOXY,
 ]
 
 VERSION = "version"
@@ -112,8 +113,7 @@ class InstanceMetadata(object):
     """Instance metadata."""
 
     def __init__(self, instance, address=None, content=None, extra_md=None,
-                 network_info=None, network_metadata=None,
-                 request_context=None):
+                 network_info=None, network_metadata=None):
         """Creation of this object should basically cover all time consuming
         collection.  Methods after that should not cause time delays due to
         network operations or lengthy cpu operations.
@@ -207,12 +207,9 @@ class InstanceMetadata(object):
         # contain the admin password for the instance, and we shouldn't
         # pass that to external services.
         self.vendordata_providers = {
-            'StaticJSON': vendordata_json.JsonFileVendorData(
-                instance=instance, address=address,
-                extra_md=extra_md, network_info=network_info),
+            'StaticJSON': vendordata_json.JsonFileVendorData(),
             'DynamicJSON': vendordata_dynamic.DynamicVendorData(
-                instance=instance, address=address,
-                network_info=network_info, context=request_context)
+                instance=instance)
         }
 
     def _route_configuration(self):
@@ -284,8 +281,8 @@ class InstanceMetadata(object):
             meta_data['public-ipv4'] = floating_ip
 
         if self._check_version('2007-08-29', version):
-            instance_type = self.instance.get_flavor()
-            meta_data['instance-type'] = instance_type['name']
+            flavor = self.instance.get_flavor()
+            meta_data['instance-type'] = flavor['name']
 
         if self._check_version('2007-12-15', version):
             meta_data['block-device-mapping'] = self.mappings
@@ -431,6 +428,12 @@ class InstanceMetadata(object):
                         device_metadata['serial'] = device.serial
                     if 'path' in device:
                         device_metadata['path'] = device.path
+                elif self._check_os_version(EPOXY, version) and isinstance(
+                    device, metadata_obj.ShareMetadata
+                ):
+                    device_metadata['type'] = 'share'
+                    device_metadata['share_id'] = device.share_id
+                    device_metadata['tag'] = device.tag
                 else:
                     LOG.debug('Metadata for device of unknown type %s has not '
                               'been included in the '
@@ -722,7 +725,7 @@ def ec2_md_print(data):
         return output[:-1]
     elif isinstance(data, list):
         return '\n'.join(data)
-    elif isinstance(data, (bytes, six.text_type)):
+    elif isinstance(data, (bytes, str)):
         return data
     else:
         return str(data)
