@@ -13,10 +13,14 @@
 #    under the License.
 
 import re
+import typing as ty
 
 from nova import exception
 from nova.i18n import _
 
+if ty.TYPE_CHECKING:
+    from nova.api.openstack import wsgi
+
 # Define the minimum and maximum version of the API across all of the
 # REST API. The format of the version is:
 # X.Y where:
@@ -256,7 +260,24 @@ REST_API_VERSION_HISTORY = """REST API Version History:
     * 2.94 - Allow FQDN in server hostname.
     * 2.95 - Evacuate will now stop instance at destination.
     * 2.96 - Add support for returning pinned_availability_zone in
-             ``server show`` and ``server list --long`` responses.
+             ``server show``, ``server list --long``, ``server update``, and
+             ``server rebuild`` responses.
+    * 2.97 - Adds new API ``GET /servers/{server_id}/shares`` which shows
+             shares attachments of a given server.
+             ``GET /servers/{server_id}/shares/{share_id} which gives details
+             about a share attachment.
+             ``POST /servers/{server_id}/shares/{share_id} which create an
+             attachment.
+             ``DELETE /servers/{server_id}/shares/{share_id} which delete an
+             attachment.
+    * 2.98 - Add support for returning embedded image properties in
+             ``server show``, ``server list --long``, `server update``, and
+             in the ``server rebuild`` responses.
+    * 2.99 - Add the spice-direct console type to the spice console protocol.
+    * 2.100 - Add support for returning associated scheduler_hints in
+             ``GET /servers/{server_id}``, ``GET /servers/detail``,
+             ``PUT /servers/{server_id}`` and
+             ``POST /server/{server_id}/action`` (rebuild) responses.
 """
 
 # The minimum and maximum versions of the API supported
@@ -265,7 +286,7 @@ REST_API_VERSION_HISTORY = """REST API Version History:
 # Note(cyeoh): This only applies for the v2.1 API once microversions
 # support is fully merged. It does not affect the V2 API.
 _MIN_API_VERSION = '2.1'
-_MAX_API_VERSION = '2.96'
+_MAX_API_VERSION = '2.100'
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 # Almost all proxy APIs which are related to network, images and baremetal
@@ -289,22 +310,22 @@ def max_api_version():
     return APIVersionRequest(_MAX_API_VERSION)
 
 
-def is_supported(req, min_version=_MIN_API_VERSION,
-                 max_version=_MAX_API_VERSION):
+def is_supported(req: 'wsgi.Request', version: str) -> bool:
     """Check if API request version satisfies version restrictions.
 
     :param req: request object
-    :param min_version: minimal version of API needed for correct
-           request processing
-    :param max_version: maximum version of API needed for correct
-           request processing
+    :param version: minimal version of API needed for correct
+        request processing
 
     :returns: True if request satisfies minimal and maximum API version
-             requirements. False in other case.
+        requirements. False in other case.
     """
+    # TODO(stephenfin): This should be an error since it highlights bugs in
+    # either our middleware or (more likely) an incomplete test
+    if req.is_legacy_v2():  # legacy requests will not pass microversion info
+        return False
 
-    return (APIVersionRequest(max_version) >= req.api_version_request >=
-            APIVersionRequest(min_version))
+    return req.api_version_request >= APIVersionRequest(version)
 
 
 class APIVersionRequest(object):
