@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
 import webob
 
 from nova.api.openstack import api_version_request
 from nova.api.openstack import common
-from nova.api.openstack.compute.schemas import flavors_extraspecs
+from nova.api.openstack.compute.schemas import flavors_extraspecs as schema
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova.api.validation.extra_specs import validators
@@ -28,6 +27,7 @@ from nova.policies import flavor_extra_specs as fes_policies
 from nova import utils
 
 
+@validation.validated
 class FlavorExtraSpecsController(wsgi.Controller):
     """The flavor extra specs API controller for the OpenStack API."""
 
@@ -36,16 +36,14 @@ class FlavorExtraSpecsController(wsgi.Controller):
         return dict(extra_specs=flavor.extra_specs)
 
     def _check_extra_specs_value(self, req, specs):
-        validation_supported = api_version_request.is_supported(
-            req, min_version='2.86',
-        )
+        validation_supported = api_version_request.is_supported(req, '2.86')
 
         for name, value in specs.items():
             # NOTE(gmann): Max length for numeric value is being checked
             # explicitly as json schema cannot have max length check for
             # numeric value
-            if isinstance(value, (six.integer_types, float)):
-                value = six.text_type(value)
+            if isinstance(value, (int, float)):
+                value = str(value)
                 try:
                     utils.check_string_length(value, 'extra_specs value',
                                               max_length=255)
@@ -57,6 +55,8 @@ class FlavorExtraSpecsController(wsgi.Controller):
                 validators.validate(name, value)
 
     @wsgi.expected_errors(404)
+    @validation.query_schema(schema.index_query)
+    @validation.response_body_schema(schema.index_response)
     def index(self, req, flavor_id):
         """Returns the list of extra specs for a given flavor."""
         context = req.environ['nova.context']
@@ -68,7 +68,8 @@ class FlavorExtraSpecsController(wsgi.Controller):
     # +microversions because the flavor extra specs has been created
     # completely when returning a response.
     @wsgi.expected_errors((400, 404, 409))
-    @validation.schema(flavors_extraspecs.create)
+    @validation.schema(schema.create)
+    @validation.response_body_schema(schema.create_response)
     def create(self, req, flavor_id, body):
         context = req.environ['nova.context']
         context.can(fes_policies.POLICY_ROOT % 'create', target={})
@@ -86,7 +87,8 @@ class FlavorExtraSpecsController(wsgi.Controller):
         return body
 
     @wsgi.expected_errors((400, 404, 409))
-    @validation.schema(flavors_extraspecs.update)
+    @validation.schema(schema.update)
+    @validation.response_body_schema(schema.update_response)
     def update(self, req, flavor_id, id, body):
         context = req.environ['nova.context']
         context.can(fes_policies.POLICY_ROOT % 'update', target={})
@@ -106,6 +108,8 @@ class FlavorExtraSpecsController(wsgi.Controller):
         return body
 
     @wsgi.expected_errors(404)
+    @validation.query_schema(schema.show_query)
+    @validation.response_body_schema(schema.show_response)
     def show(self, req, flavor_id, id):
         """Return a single extra spec item."""
         context = req.environ['nova.context']
@@ -124,6 +128,7 @@ class FlavorExtraSpecsController(wsgi.Controller):
     # +microversions because the flavor extra specs has been deleted
     # completely when returning a response.
     @wsgi.expected_errors(404)
+    @validation.response_body_schema(schema.delete_response)
     def delete(self, req, flavor_id, id):
         """Deletes an existing extra spec."""
         context = req.environ['nova.context']
