@@ -26,28 +26,33 @@ It was removed in the 18.0.0 (Rocky) release.
 """
 
 
+@validation.validated
 class FloatingIPBulkController(wsgi.Controller):
 
     @wsgi.expected_errors(410)
     @wsgi.removed('18.0.0', _removal_reason)
     @validation.query_schema(schema.index_query)
+    @validation.response_body_schema(schema.index_response)
     def index(self, req):
         raise exc.HTTPGone()
 
     @wsgi.expected_errors(410)
     @wsgi.removed('18.0.0', _removal_reason)
     @validation.query_schema(schema.show_query)
+    @validation.response_body_schema(schema.show_response)
     def show(self, req, id):
         raise exc.HTTPGone()
 
     @wsgi.expected_errors(410)
     @wsgi.removed('18.0.0', _removal_reason)
     @validation.schema(schema.create)
+    @validation.response_body_schema(schema.create_response)
     def create(self, req, body):
         raise exc.HTTPGone()
 
     @wsgi.expected_errors(410)
     @wsgi.removed('18.0.0', _removal_reason)
     @validation.schema(schema.update)
+    @validation.response_body_schema(schema.update_response)
     def update(self, req, id, body):
         raise exc.HTTPGone()
