@@ -16,11 +16,10 @@
 """The hosts admin extension."""
 
 from oslo_log import log as logging
-import six
 import webob.exc
 
 from nova.api.openstack import common
-from nova.api.openstack.compute.schemas import hosts
+from nova.api.openstack.compute.schemas import hosts as schema
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova.compute import api as compute
@@ -32,15 +31,18 @@ from nova.policies import hosts as hosts_policies
 LOG = logging.getLogger(__name__)
 
 
+@validation.validated
 class HostController(wsgi.Controller):
     """The Hosts API controller for the OpenStack API."""
+
     def __init__(self):
         super(HostController, self).__init__()
         self.api = compute.HostAPI()
 
-    @wsgi.Controller.api_version("2.1", "2.42")
-    @validation.query_schema(hosts.index_query)
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors(())
+    @validation.query_schema(schema.index_query)
+    @validation.response_body_schema(schema.index_response)
     def index(self, req):
         """Returns a dict in the format
 
@@ -88,9 +90,10 @@ class HostController(wsgi.Controller):
                               'zone': service['availability_zone']})
         return {'hosts': hosts}
 
-    @wsgi.Controller.api_version("2.1", "2.42")
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors((400, 404, 501))
-    @validation.schema(hosts.update)
+    @validation.schema(schema.update)
+    @validation.response_body_schema(schema.update_response)
     def update(self, req, id, body):
         """Return booleanized version of body dict.
 
@@ -180,24 +183,30 @@ class HostController(wsgi.Controller):
             raise webob.exc.HTTPBadRequest(explanation=e.format_message())
         return {"host": host_name, "power_action": result}
 
-    @wsgi.Controller.api_version("2.1", "2.42")
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors((400, 404, 501))
+    @validation.query_schema(schema.startup_query)
+    @validation.response_body_schema(schema.startup_response)
     def startup(self, req, id):
         context = req.environ['nova.context']
         context.can(hosts_policies.POLICY_NAME % 'start',
                     target={})
         return self._host_power_action(req, host_name=id, action="startup")
 
-    @wsgi.Controller.api_version("2.1", "2.42")
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors((400, 404, 501))
+    @validation.query_schema(schema.shutdown_query)
+    @validation.response_body_schema(schema.shutdown_response)
     def shutdown(self, req, id):
         context = req.environ['nova.context']
         context.can(hosts_policies.POLICY_NAME % 'shutdown',
                     target={})
         return self._host_power_action(req, host_name=id, action="shutdown")
 
-    @wsgi.Controller.api_version("2.1", "2.42")
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors((400, 404, 501))
+    @validation.query_schema(schema.reboot_query)
+    @validation.response_body_schema(schema.reboot_response)
     def reboot(self, req, id):
         context = req.environ['nova.context']
         context.can(hosts_policies.POLICY_NAME % 'reboot',
@@ -253,8 +262,10 @@ class HostController(wsgi.Controller):
                                     instance['ephemeral_gb'])
         return project_map
 
-    @wsgi.Controller.api_version("2.1", "2.42")
+    @wsgi.api_version("2.1", "2.42")
     @wsgi.expected_errors(404)
+    @validation.query_schema(schema.show_query)
+    @validation.response_body_schema(schema.show_response)
     def show(self, req, id):
         """Shows the physical/usage resource given by hosts.
 
@@ -287,6 +298,6 @@ class HostController(wsgi.Controller):
                                                                   instances))
         by_proj_resources = self._get_resources_by_project(host_name,
                                                            instances)
-        for resource in six.itervalues(by_proj_resources):
+        for resource in by_proj_resources.values():
             resources.append({'resource': resource})
         return {'host': resources}
