@@ -44,3 +44,15 @@ reset_state = {
     'required': ['os-resetState'],
     'additionalProperties': False,
 }
+
+# NOTE(stephenfin): This schema is intentionally empty since the action has
+# been removed
+reset_network_response = {}
+
+inject_network_info_response = {
+    'type': 'null',
+}
+
+reset_state_response = {
+    'type': 'null',
+}
