@@ -12,12 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
+
 get_vnc_console = {
     'type': 'object',
     'properties': {
         'os-getVNCConsole': {
             'type': 'object',
             'properties': {
+                # NOTE(stephenfin): While we only support novnc nowadays, we
+                # previously supported xvpvnc for the XenServer driver. Since
+                # our generated schemas are unversioned, we need to accept
+                # these old values here and reject them lower down the stack.
+                # Ditto for other schemas in this file.
                 'type': {
                     'type': 'string',
                     'enum': ['novnc', 'xvpvnc'],
@@ -61,8 +68,7 @@ get_serial_console = {
             'type': 'object',
             'properties': {
                 'type': {
-                    'type': 'string',
-                    'enum': ['serial'],
+                    'type': 'string', 'enum': ['serial'],
                 },
             },
             'required': ['type'],
@@ -81,11 +87,16 @@ create_v26 = {
             'properties': {
                 'protocol': {
                     'type': 'string',
-                    'enum': ['vnc', 'spice', 'serial'],
+                    # While we no longer support the rdp console type, we still
+                    # list it here for documentation purposes. It is rejected
+                    # at the controller level.
+                    'enum': ['vnc', 'spice', 'serial', 'rdp'],
                 },
                 'type': {
                     'type': 'string',
-                    'enum': ['novnc', 'xvpvnc', 'spice-html5', 'serial'],
+                    'enum': [
+                        'novnc', 'xvpvnc', 'spice-html5', 'serial', 'rdp-html5'
+                    ],
                 },
             },
             'required': ['protocol', 'type'],
@@ -96,53 +107,18 @@ create_v26 = {
     'additionalProperties': False,
 }
 
-create_v28 = {
-    'type': 'object',
-    'properties': {
-        'remote_console': {
-            'type': 'object',
-            'properties': {
-                'protocol': {
-                    'type': 'string',
-                    'enum': ['vnc', 'spice', 'serial', 'mks'],
-                },
-                'type': {
-                    'type': 'string',
-                    'enum': ['novnc', 'xvpvnc', 'spice-html5', 'serial',
-                             'webmks'],
-                },
-            },
-            'required': ['protocol', 'type'],
-            'additionalProperties': False,
-        },
-    },
-    'required': ['remote_console'],
-    'additionalProperties': False,
-}
+create_v28 = copy.deepcopy(create_v26)
+create_v28['properties']['remote_console']['properties']['protocol'][
+    'enum'
+].append('mks')
+create_v28['properties']['remote_console']['properties']['type'][
+    'enum'
+].append('webmks')
 
-create_v299 = {
-    'type': 'object',
-    'properties': {
-        'remote_console': {
-            'type': 'object',
-            'properties': {
-                'protocol': {
-                    'type': 'string',
-                    'enum': ['vnc', 'spice', 'rdp', 'serial', 'mks'],
-                },
-                'type': {
-                    'type': 'string',
-                    'enum': ['novnc', 'xvpvnc', 'spice-html5', 'spice-direct',
-                             'serial', 'webmks'],
-                },
-            },
-            'required': ['protocol', 'type'],
-            'additionalProperties': False,
-        },
-    },
-    'required': ['remote_console'],
-    'additionalProperties': False,
-}
+create_v299 = copy.deepcopy(create_v28)
+create_v299['properties']['remote_console']['properties']['type'][
+    'enum'
+].append('spice-direct')
 
 get_vnc_console_response = {
     'type': 'object',
@@ -150,16 +126,8 @@ get_vnc_console_response = {
         'console': {
             'type': 'object',
             'properties': {
-                'type': {
-                    'type': 'string',
-                    'enum': ['novnc', 'xvpvnc'],
-                    'description': '',
-                },
-                'url': {
-                    'type': 'string',
-                    'format': 'uri',
-                    'description': '',
-                },
+                'type': {'type': 'string', 'enum': ['novnc', 'xvpvnc']},
+                'url': {'type': 'string', 'format': 'uri'},
             },
             'required': ['type', 'url'],
             'additionalProperties': False,
@@ -175,16 +143,24 @@ get_spice_console_response = {
         'console': {
             'type': 'object',
             'properties': {
-                'type': {
-                    'type': 'string',
-                    'enum': ['spice-html5'],
-                    'description': '',
-                },
-                'url': {
-                    'type': 'string',
-                    'format': 'uri',
-                    'description': '',
-                },
+                'type': {'type': 'string', 'const': 'spice-html5'},
+                'url': {'type': 'string', 'format': 'uri'},
+            },
+            'required': ['type', 'url'],
+            'additionalProperties': False,
+        },
+    },
+    'additionalProperties': False,
+}
+
+get_rdp_console_response = {
+    'type': 'object',
+    'properties': {
+        'console': {
+            'type': 'object',
+            'properties': {
+                'type': {'type': 'string', 'const': 'rdp-html5'},
+                'url': {'type': 'string', 'format': 'uri'},
             },
             'required': ['type', 'url'],
             'additionalProperties': False,
@@ -200,16 +176,8 @@ get_serial_console_response = {
         'console': {
             'type': 'object',
             'properties': {
-                'type': {
-                    'type': 'string',
-                    'enum': ['serial'],
-                    'description': '',
-                },
-                'url': {
-                    'type': 'string',
-                    'format': 'uri',
-                    'description': '',
-                },
+                'type': {'type': 'string', 'const': 'serial'},
+                'url': {'type': 'string', 'format': 'uri'},
             },
             'required': ['type', 'url'],
             'additionalProperties': False,
@@ -218,3 +186,42 @@ get_serial_console_response = {
     'required': ['console'],
     'additionalProperties': False,
 }
+
+create_response = {
+    'type': 'object',
+    'properties': {
+        'remote_console': {
+            'type': 'object',
+            'properties': {
+                'protocol': {
+                    'type': 'string',
+                    'enum': ['vnc', 'spice', 'serial', 'rdp'],
+                },
+                'type': {
+                    'type': 'string',
+                    'enum': [
+                        'novnc', 'xvpvnc', 'spice-html5', 'serial', 'rdp-html5'
+                    ],
+                },
+                'url': {'type': 'string', 'format': 'uri'},
+            },
+            'required': ['protocol', 'type', 'url'],
+            'additionalProperties': False,
+        },
+    },
+    'required': ['remote_console'],
+    'additionalProperties': False,
+}
+
+create_response_v28 = copy.deepcopy(create_response)
+create_response_v28['properties']['remote_console']['properties'][
+    'protocol'
+]['enum'].append('mks')
+create_response_v28['properties']['remote_console']['properties'][
+    'type'
+]['enum'].append('webmks')
+
+create_response_v299 = copy.deepcopy(create_response_v28)
+create_response_v299['properties']['remote_console']['properties'][
+    'type'
+]['enum'].append('spice-direct')
