@@ -32,9 +32,6 @@ from nova.scheduler.client import report
 from nova import servicegroup
 from nova import utils
 
-UUID_FOR_ID_MIN_VERSION = '2.53'
-PARTIAL_CONSTRUCT_FOR_CELL_DOWN_MIN_VERSION = '2.69'
-
 LOG = logging.getLogger(__name__)
 
 
@@ -61,8 +58,7 @@ class ServiceController(wsgi.Controller):
 
         context = req.environ['nova.context']
 
-        cell_down_support = api_version_request.is_supported(
-            req, min_version=PARTIAL_CONSTRUCT_FOR_CELL_DOWN_MIN_VERSION)
+        cell_down_support = api_version_request.is_supported(req, '2.69')
 
         _services = [
             s
@@ -101,8 +97,7 @@ class ServiceController(wsgi.Controller):
             active = 'disabled'
         updated_time = self.servicegroup_api.get_updated_time(svc)
 
-        uuid_for_id = api_version_request.is_supported(
-            req, min_version=UUID_FOR_ID_MIN_VERSION)
+        uuid_for_id = api_version_request.is_supported(req, '2.53')
 
         if 'availability_zone' not in svc:
             # The service wasn't loaded with the AZ so we need to do it here.
@@ -130,8 +125,7 @@ class ServiceController(wsgi.Controller):
 
     def _get_services_list(self, req, additional_fields=()):
         _services = self._get_services(req)
-        cell_down_support = api_version_request.is_supported(req,
-            min_version=PARTIAL_CONSTRUCT_FOR_CELL_DOWN_MIN_VERSION)
+        cell_down_support = api_version_request.is_supported(req, '2.69')
         return [self._get_service_detail(svc, additional_fields, req,
                 cell_down_support=cell_down_support) for svc in _services]
 
@@ -251,8 +245,7 @@ class ServiceController(wsgi.Controller):
         context = req.environ['nova.context']
         context.can(services_policies.BASE_POLICY_NAME % 'delete', target={})
 
-        if api_version_request.is_supported(
-                req, min_version=UUID_FOR_ID_MIN_VERSION):
+        if api_version_request.is_supported(req, '2.53'):
             if not uuidutils.is_uuid_like(id):
                 msg = _('Invalid uuid %s') % id
                 raise webob.exc.HTTPBadRequest(explanation=msg)
@@ -373,26 +366,26 @@ class ServiceController(wsgi.Controller):
                         'in-progress migrations. Complete the '
                         'migrations or delete the instances first.'))
 
-    @validation.query_schema(services.index_query_schema_275, '2.75')
-    @validation.query_schema(services.index_query_schema, '2.0', '2.74')
     @wsgi.expected_errors(())
+    @validation.query_schema(services.index_query_schema, '2.0', '2.74')
+    @validation.query_schema(services.index_query_schema_275, '2.75')
     def index(self, req):
         """Return a list of all running services. Filter by host & service
         name
         """
         context = req.environ['nova.context']
         context.can(services_policies.BASE_POLICY_NAME % 'list', target={})
-        if api_version_request.is_supported(req, min_version='2.11'):
+        if api_version_request.is_supported(req, '2.11'):
             _services = self._get_services_list(req, ['forced_down'])
         else:
             _services = self._get_services_list(req)
 
         return {'services': _services}
 
-    @wsgi.Controller.api_version('2.1', '2.52')
     @wsgi.expected_errors((400, 404))
     @validation.schema(services.service_update, '2.0', '2.10')
     @validation.schema(services.service_update_v211, '2.11', '2.52')
+    @validation.schema(services.service_update_v253, '2.53')
     def update(self, req, id, body):
         """Perform service update
 
@@ -400,10 +393,20 @@ class ServiceController(wsgi.Controller):
         to identify the service on which to perform the action. There is no
         service ID passed on the path, just the action, for example
         PUT /os-services/disable.
+
+        Starting with microversion 2.53, the service uuid is passed in on the
+        path of the request to uniquely identify the service record on which to
+        perform a given update, which is defined in the body of the request.
         """
+        if api_version_request.is_supported(req, '2.53'):
+            return self._update_v253(req, id, body)
+        else:
+            return self._update_v21(req, id, body)
+
+    def _update_v21(self, req, id, body):
         context = req.environ['nova.context']
         context.can(services_policies.BASE_POLICY_NAME % 'update', target={})
-        if api_version_request.is_supported(req, min_version='2.11'):
+        if api_version_request.is_supported(req, '2.11'):
             actions = self.actions.copy()
             actions["force-down"] = self._forced_down
         else:
@@ -411,16 +414,7 @@ class ServiceController(wsgi.Controller):
 
         return self._perform_action(req, id, body, actions)
 
-    @wsgi.Controller.api_version(UUID_FOR_ID_MIN_VERSION)  # noqa F811
-    @wsgi.expected_errors((400, 404))
-    @validation.schema(services.service_update_v2_53, UUID_FOR_ID_MIN_VERSION)
-    def update(self, req, id, body):   # noqa
-        """Perform service update
-
-        Starting with microversion 2.53, the service uuid is passed in on the
-        path of the request to uniquely identify the service record on which to
-        perform a given update, which is defined in the body of the request.
-        """
+    def _update_v253(self, req, id, body):
         service_id = id
         # Validate that the service ID is a UUID.
         if not uuidutils.is_uuid_like(service_id):
