@@ -33,10 +33,10 @@ LINKS = {
 VERSIONS = {
     "v2.0": {
         "id": "v2.0",
-        "status": "SUPPORTED",
+        "status": "DEPRECATED",
         "version": "",
         "min_version": "",
-        "updated": "2011-01-21T11:33:21Z",
+        "updated": "2025-07-04T12:00:00Z",
         "links": [
             {
                 "rel": "describedby",
@@ -74,6 +74,7 @@ VERSIONS = {
 }
 
 
+@validation.validated
 class Versions(wsgi.Resource):
 
     # The root version API isn't under the microversion control.
@@ -108,6 +109,7 @@ class Versions(wsgi.Resource):
         return args
 
 
+@validation.validated
 class VersionsV2(wsgi.Resource):
 
     def __init__(self):
