@@ -72,7 +72,7 @@ cpu_policy_validators = [
             'individually pinned to their own host core. '
             'If ``mixed``, the policy for each instance CPU can be specified '
             'using the ``hw:cpu_dedicated_mask`` or ``hw:cpu_realtime_mask`` '
-            'extra specs.'
+            'extra specs. '
             'Only supported by the libvirt virt driver.'
         ),
         value={
@@ -167,7 +167,7 @@ hugepage_validators = [
         name='hw:locked_memory',
         description=(
             'Determine if **guest** (instance) memory should be locked '
-            'preventing swaping. This is required in rare cases for device '
+            'preventing swapping. This is required in rare cases for device '
             'DMA transfers. Only supported by the libvirt virt driver.'
         ),
         value={
@@ -250,7 +250,7 @@ numa_validators = [
         description=(
             'The NUMA affinity policy of any PCI passthrough devices or '
             'SR-IOV network interfaces attached to the instance. '
-            'If ``required`, only PCI devices from one of the host NUMA '
+            'If ``required``, only PCI devices from one of the host NUMA '
             'nodes the instance VCPUs are allocated from can be used by said '
             'instance. '
             'If ``preferred``, any PCI device can be used, though preference '
@@ -278,7 +278,7 @@ cpu_topology_validators = [
     base.ExtraSpecValidator(
         name='hw:cpu_sockets',
         description=(
-            'The number of virtual CPU threads to emulate in the guest '
+            'The number of virtual CPU sockets to emulate in the guest '
             'CPU topology. '
             'Defaults to the number of vCPUs requested. '
             'Only supported by the libvirt virt driver.'
@@ -294,7 +294,7 @@ cpu_topology_validators = [
         description=(
             'The number of virtual CPU cores to emulate per socket in the '
             'guest CPU topology. '
-            'Defaults to ``1``.'
+            'Defaults to ``1``. '
             'Only supported by the libvirt virt driver. '
         ),
         value={
@@ -307,7 +307,7 @@ cpu_topology_validators = [
         name='hw:cpu_threads',
         description=(
             'The number of virtual CPU threads to emulate per core in the '
-            'guest CPU topology.'
+            'guest CPU topology. '
             'Defaults to ``1``. '
             'Only supported by the libvirt virt driver. '
         ),
@@ -318,9 +318,9 @@ cpu_topology_validators = [
         },
     ),
     base.ExtraSpecValidator(
-        name='hw:max_cpu_sockets',
+        name='hw:cpu_max_sockets',
         description=(
-            'The max number of virtual CPU threads to emulate in the '
+            'The max number of virtual CPU sockets to emulate in the '
             'guest CPU topology. '
             'This is used to limit the topologies that can be requested by '
             'an image and will be used to validate the ``hw_cpu_sockets`` '
@@ -334,7 +334,7 @@ cpu_topology_validators = [
         },
     ),
     base.ExtraSpecValidator(
-        name='hw:max_cpu_cores',
+        name='hw:cpu_max_cores',
         description=(
             'The max number of virtual CPU cores to emulate per socket in the '
             'guest CPU topology. '
@@ -350,7 +350,7 @@ cpu_topology_validators = [
         },
     ),
     base.ExtraSpecValidator(
-        name='hw:max_cpu_threads',
+        name='hw:cpu_max_threads',
         description=(
             'The max number of virtual CPU threads to emulate per core in the '
             'guest CPU topology. '
@@ -407,6 +407,22 @@ feature_flag_validators = [
             'description': 'Whether to enable memory encryption',
         },
     ),
+    base.ExtraSpecValidator(
+        name='hw:mem_encryption_model',
+        description=(
+            'CPU feature used for memory encryption of the guest. '
+            'This has no effect unless hw:mem_encryption (or equivalent '
+            'image property) is set to True.'
+        ),
+        value={
+            'type': str,
+            'description': 'A CPU feature used for memory encryption',
+            'enum': [
+                'amd-sev',
+                'amd-sev-es',
+            ],
+        },
+    ),
     base.ExtraSpecValidator(
         name='hw:pmem',
         description=(
@@ -527,6 +543,58 @@ feature_flag_validators = [
             'description': 'model for vIOMMU',
         },
     ),
+    base.ExtraSpecValidator(
+        name='hw:virtio_packed_ring',
+        description=(
+            'Permit guests to negotiate the virtio packed ring format. '
+            'This requires guest support and is only supported by '
+            'the libvirt driver.'
+        ),
+        value={
+            'type': bool,
+            'description': 'Whether to enable packed virtqueue',
+        },
+    ),
+    base.ExtraSpecValidator(
+        name='hw:sound_model',
+        description=(
+            'The model of the attached sound device. '
+            'Only supported by the libvirt virt driver. '
+            'If unset, no sound device is attached.'
+        ),
+        value={
+            'type': str,
+            'description': 'A sound model',
+            'enum': fields.SoundModelType.ALL,
+        },
+    ),
+    base.ExtraSpecValidator(
+        name='hw:usb_model',
+        description=(
+            'The model of the attached USB controller device. '
+            'Only supported by the libvirt virt driver. '
+            'If unset, no USB controller device is attached.'
+        ),
+        value={
+            'type': str,
+            'description': 'A USB controller model',
+            'enum': fields.USBControllerModelType.ALL,
+        },
+    ),
+    base.ExtraSpecValidator(
+        name='hw:redirected_usb_ports',
+        description=(
+            'The number of redirected USB ports to add to the virtual '
+            'machine. Only supported by the libvirt virt driver. If unset, '
+            'no redirected USB ports are added. The maximum value is 15.'
+        ),
+        value={
+            'type': int,
+            'description': 'The number of USB redirection devices to add',
+            'min': 0,
+            'max': 15
+        },
+    ),
 ]
 
 ephemeral_encryption_validators = [
