@@ -52,7 +52,9 @@ bdm_new_fields = set(['source_type', 'destination_type',
                      'guest_format', 'device_type', 'disk_bus', 'boot_index',
                      'device_name', 'delete_on_termination', 'snapshot_id',
                      'volume_id', 'volume_size', 'image_id', 'no_device',
-                     'connection_info', 'tag', 'volume_type'])
+                     'connection_info', 'tag', 'volume_type', 'encrypted',
+                     'encryption_secret_uuid', 'encryption_format',
+                     'encryption_options'])
 
 
 bdm_db_only_fields = set(['id', 'instance_uuid', 'attachment_id', 'uuid'])
@@ -311,30 +313,6 @@ def snapshot_from_bdm(snapshot_id, template):
     return BlockDeviceDict(snapshot_dict)
 
 
-def legacy_mapping(block_device_mapping):
-    """Transform a list of block devices of an instance back to the
-    legacy data format.
-    """
-
-    legacy_block_device_mapping = []
-
-    for bdm in block_device_mapping:
-        try:
-            legacy_block_device = BlockDeviceDict(bdm).legacy()
-        except exception.InvalidBDMForLegacy:
-            continue
-
-        legacy_block_device_mapping.append(legacy_block_device)
-
-    # Re-enumerate the ephemeral devices
-    for i, dev in enumerate(dev for dev in legacy_block_device_mapping
-                            if dev['virtual_name'] and
-                            is_ephemeral(dev['virtual_name'])):
-        dev['virtual_name'] = dev['virtual_name'][:-1] + str(i)
-
-    return legacy_block_device_mapping
-
-
 def from_legacy_mapping(legacy_block_device_mapping, image_uuid='',
                         root_device_name=None, no_root=False):
     """Transform a legacy list of block devices to the new data format."""
@@ -636,7 +614,7 @@ def get_bdm_local_disk_num(block_device_mappings):
 
 def get_bdm_image_metadata(context, image_api, volume_api,
                            block_device_mapping, legacy_bdm=True):
-    """Attempt to retrive image metadata from a given block_device_mapping.
+    """Attempt to retrieve image metadata from a given block_device_mapping.
 
     If we are booting from a volume, we need to get the volume details from
     Cinder and make sure we pass the metadata back accordingly.
