@@ -62,11 +62,50 @@ entry.
         help='Explicitly specify the temporary working directory.'),
     cfg.IntOpt(
         'default_green_pool_size',
+        deprecated_for_removal=True,
+        deprecated_since='32.0.0',
+        deprecated_reason="""
+This option is only used if the service is running in Eventlet mode. When
+that mode is removed this config option will be removed too.
+""",
         default=1000,
         min=100,
         help='''
 The total number of coroutines that can be run via nova's default
-greenthread pool concurrently, defaults to 1000, min value is 100.
+greenthread pool concurrently, defaults to 1000, min value is 100. It is only
+used if the service is running in Eventlet mode.
+'''),
+    cfg.IntOpt(
+        'default_thread_pool_size',
+        default=10,
+        min=1,
+        help='''
+The total number of threads that can be run via nova's default
+thread pool concurrently. It is only used if the service is running in
+native threading mode.
+'''),
+    cfg.IntOpt(
+        'cell_worker_thread_pool_size',
+        default=5,
+        min=1,
+        help='''
+The number of tasks that can run concurrently, one for each cell, for
+operations requires cross cell data gathering a.k.a scatter-gather, like
+listing instances across multiple cells. This is only used if the service is
+running in native thread mode.
+'''),
+    cfg.IntOpt(
+        'thread_pool_statistic_period',
+        default=-1,
+        min=-1,
+        help='''
+When new work is submitted to any of the thread pools nova logs the
+statistics of the pool (work executed, threads available, work queued, etc).
+This parameter defines how frequently such logging happens from a specific
+pool in seconds. A value of 60 means that statistic will be logged
+from a pool maximum once every 60 seconds. The value 0 means that logging
+happens every time work is submitted to the pool. The value -1 means the
+logging is disabled.
 '''),
 ]
 
