@@ -118,6 +118,7 @@ Related options:
 * ``disk_prefix``: depends on this
 * ``cpu_mode``: depends on this
 * ``cpu_models``: depends on this
+* ``tb_cache_size``: depends on this
 """),
     cfg.StrOpt('connection_uri',
                default='',
@@ -324,11 +325,11 @@ Please refer to the libvirt documentation for further details.
 Target maximum period of time Nova will try to keep the instance paused
 during the last part of the memory copy, in *milliseconds*.
 
-Will be rounded up to a minimum of 100ms. You can increase this value
-if you want to allow live-migrations to complete faster, or avoid
-live-migration timeout errors by allowing the guest to be paused for
-longer during the live-migration switch over. This value may be exceeded
-if there is any reduction on the transfer rate after the VM is paused.
+Minimum downtime is 100ms. You can increase this value if you want to allow
+live-migrations to complete faster, or avoid live-migration timeout errors
+by allowing the guest to be paused for longer during the live-migration switch
+over. This value may be exceeded if there is any reduction on the transfer rate
+after the VM is paused.
 
 Related options:
 
@@ -340,7 +341,7 @@ Related options:
                help="""
 Number of incremental steps to reach max downtime value.
 
-Will be rounded up to a minimum of 3 steps.
+Minimum number of steps is 3.
 """),
     cfg.IntOpt('live_migration_downtime_delay',
                default=75,
@@ -601,7 +602,7 @@ disable certain CPU features.  An example of this is Intel's "invtsc"
 flag to a Nova instance, you need to explicitly enable it.
 
 The possible values for ``cpu_model_extra_flags`` depends on the CPU
-model in use.  Refer to `/usr/share/libvirt/cpu_map/*.xml`` for possible
+model in use.  Refer to ``/usr/share/libvirt/cpu_map/*.xml`` for possible
 CPU feature flags for a given CPU model.
 
 A special note on a particular CPU flag: ``pcid`` (an Intel processor
@@ -839,6 +840,13 @@ Related options:
     cfg.IntOpt('num_memory_encrypted_guests',
                default=None,
                min=0,
+               deprecated_for_removal=True,
+               deprecated_since='32.0.0',
+               deprecated_reason="""
+This option is effective for only SEV and has no effect for SEV-ES. Libvirt
+is capable to present maximum number of SEV guests and one of SEV-ES guests
+since 8.0.0 and this option is no longer necessary.
+""",
                help="""
 Maximum number of guests with encrypted memory which can run
 concurrently on this compute host.
@@ -853,14 +861,15 @@ The option may be reused for other equivalent technologies in the
 future.  If the machine does not support memory encryption, the option
 will be ignored and inventory will be set to 0.
 
-If the machine does support memory encryption, *for now* a value of
-``None`` means an effectively unlimited inventory, i.e. no limit will
-be imposed by Nova on the number of SEV guests which can be launched,
-even though the underlying hardware will enforce its own limit.
-However it is expected that in the future, auto-detection of the
-inventory from the hardware will become possible, at which point
-``None`` will cause auto-detection to automatically impose the correct
-limit.
+If the machine does support memory encryption and this option is not set,
+the driver detects maximum number of SEV guests from the libvirt API which
+is available since v8.0.0. Setting this option overrides the detected limit,
+unless the given value is not larger than the detected limit.
+
+On the other hand, if an older version of libvirt is used, ``None`` means
+an effectively unlimited inventory, i.e. no limit will be imposed by Nova
+on the number of SEV guests which can be launched, even though the underlying
+hardware will enforce its own limit.
 
 .. note::
 
@@ -900,6 +909,43 @@ Related options:
 
 * :oslo.config:option:`libvirt.device_detach_attempts`
 
+"""),
+    cfg.IntOpt('tb_cache_size',
+                min=0,
+                help="""
+Qemu>=5.0.0 bumped the default tb-cache size to 1GiB(from 32MiB) and this
+made it difficult to run multiple guest VMs on systems running with lower
+memory. With Libvirt>=8.0.0 this config option can be used to configure
+lower tb-cache size.
+
+Set it to > 0 to configure tb-cache for guest VMs.
+
+Related options:
+
+* ``compute_driver`` (libvirt)
+* ``virt_type`` (qemu)
+"""),
+
+    cfg.StrOpt('migration_inbound_addr',
+                       default='$my_ip',
+                       help="""
+The address used as the migration address for this host.
+
+This option indicates the IP address, hostname, or FQDN which should be used as
+the target for cold migration, resize, and evacuate traffic when moving to this
+hypervisor. This metadata is then used by the source of the migration traffic
+to construct the commands used to copy data (e.g. disk image) to the
+destination.
+
+An included "%s" is replaced with the hostname of the migration target
+hypervisor.
+
+
+Related options:
+
+* ``my_ip``
+* ``live_migration_inbound_addr``
+
 """),
 ]
 
@@ -1073,6 +1119,22 @@ Use multipath connection of the iSCSI or FC volume
 
 Volumes can be connected in the LibVirt as multipath devices. This will
 provide high availability and fault tolerance.
+"""),
+    cfg.BoolOpt('volume_enforce_multipath',
+                default=False,
+                help="""
+Require multipathd when attaching a volume to an instance.
+
+When enabled, attachment of volumes will be aborted when multipathd is not
+running. Otherwise, it will fallback to single path without error.
+
+When enabled, the libvirt driver checks availability of mulitpathd when it is
+initialized, and the compute service fails to start if multipathd is not
+running.
+
+Related options:
+
+* volume_use_multipath must be True when this is True
 """),
     cfg.IntOpt('num_volume_scan_tries',
                deprecated_name='num_iscsi_scan_tries',
@@ -1201,9 +1263,43 @@ Possible values:
 """),
 ]
 
+libvirt_volume_ceph_opts = [
+    cfg.StrOpt('ceph_mount_point_base',
+               default=paths.state_path_def('mnt'),
+               help="""
+Directory where the ceph volume for each manila share is mounted on the
+compute node.
+The default is 'mnt' directory of the location where nova's Python module
+is installed.
+
+Possible values:
+
+* A string representing absolute path of mount point.
+"""),
+    cfg.ListOpt('ceph_mount_options',
+               help="""
+Mount options passed to the ceph client. See section of the ceph man page
+for details.
+
+Mount options controls the way the filesystem is mounted and how the
+ceph client behaves when accessing files on this mount point.
+
+Possible values:
+
+* Any string representing mount options separated by commas.
+* Example string: vers=3,lookupcache=pos
+"""),
+]
+
 libvirt_volume_quobyte_opts = [
     cfg.StrOpt('quobyte_mount_point_base',
                default=paths.state_path_def('mnt'),
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Quobyte volume driver in cinder was marked unsupported. Quobyte volume support
+will be removed from nova when the volume driver is removed from cinder.
+""",
                help="""
 Directory where the Quobyte volume is mounted on the compute node.
 
@@ -1216,17 +1312,37 @@ Possible values:
 * A string representing absolute path of mount point.
 """),
     cfg.StrOpt('quobyte_client_cfg',
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Quobyte volume driver in cinder was marked unsupported. Quobyte volume support
+will be removed from nova when the volume driver is removed from cinder.
+""",
                help='Path to a Quobyte Client configuration file.'),
 ]
 
 libvirt_volume_smbfs_opts = [
     cfg.StrOpt('smbfs_mount_point_base',
                default=paths.state_path_def('mnt'),
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Windows SMB volume driver in cinder was marked unsupported. SMBFS volume
+support will be removed from nova when the volume driver is removed from
+cinder.
+""",
                help="""
 Directory where the SMBFS shares are mounted on the compute node.
 """),
     cfg.StrOpt('smbfs_mount_options',
                default='',
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Windows SMB volume driver in cinder was marked unsupported. SMBFS volume
+support will be removed from nova when the volume driver is removed from
+cinder.
+""",
                help="""
 Mount options passed to the SMBFS client.
 
@@ -1256,6 +1372,13 @@ compute nodes, other method must be used for:
 libvirt_volume_vzstorage_opts = [
     cfg.StrOpt('vzstorage_mount_point_base',
                default=paths.state_path_def('mnt'),
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Virtuozzo Storage volume driver in cinder was marked unsupported. Virtuozzo
+Storage volume support will be removed from nova when the volume driver is
+removed from cinder.
+""",
                help="""
 Directory where the Virtuozzo Storage clusters are mounted on the compute
 node.
@@ -1269,6 +1392,13 @@ Related options:
               ),
     cfg.StrOpt('vzstorage_mount_user',
                default='stack',
+               deprecated_for_removal=True,
+               deprecated_since="31.0.0",
+               deprecated_reason="""
+Virtuozzo Storage volume driver in cinder was marked unsupported. Virtuozzo
+Storage volume support will be removed from nova when the volume driver is
+removed from cinder.
+""",
                help="""
 Mount owner user name.
 
@@ -1478,6 +1608,23 @@ Related options:
 """),
 ]
 
+libvirt_cpu_mgmt_opts = [
+    cfg.BoolOpt('cpu_power_management',
+                default=False,
+                help='Use libvirt to manage CPU cores performance.'),
+    cfg.StrOpt('cpu_power_management_strategy',
+               choices=['cpu_state', 'governor'],
+               default='cpu_state',
+               help='Tuning strategy to reduce CPU power consumption when '
+                    'unused'),
+    cfg.StrOpt('cpu_power_governor_low',
+               default='powersave',
+               help='Governor to use in order '
+                    'to reduce CPU power consumption'),
+    cfg.StrOpt('cpu_power_governor_high',
+             default='performance',
+             help='Governor to use in order to have best CPU performance'),
+]
 
 ALL_OPTS = list(itertools.chain(
     libvirt_general_opts,
@@ -1491,6 +1638,7 @@ ALL_OPTS = list(itertools.chain(
     libvirt_volume_iser_opts,
     libvirt_volume_net_opts,
     libvirt_volume_nfs_opts,
+    libvirt_volume_ceph_opts,
     libvirt_volume_quobyte_opts,
     libvirt_volume_smbfs_opts,
     libvirt_remotefs_opts,
@@ -1499,6 +1647,7 @@ ALL_OPTS = list(itertools.chain(
     libvirt_volume_nvmeof_opts,
     libvirt_pmem_opts,
     libvirt_vtpm_opts,
+    libvirt_cpu_mgmt_opts,
 ))
 
 
