@@ -84,6 +84,59 @@ Agent. With the Spice agent installed the following features are enabled:
 * Better mouse integration - The mouse can be captured and released without
   needing to click inside the console or press keys to release it. The
   performance of mouse movement is also improved.
+"""),
+    cfg.StrOpt('image_compression',
+        advanced=True,
+        choices=[
+            ('auto_glz', 'enable image compression mode to choose between glz '
+             'and quic algorithm, based on image properties'),
+            ('auto_lz', 'enable image compression mode to choose between lz '
+             'and quic algorithm, based on image properties'),
+            ('quic', 'enable image compression based on the SFALIC algorithm'),
+            ('glz', 'enable image compression using lz with history based '
+             'global dictionary'),
+            ('lz', 'enable image compression with the Lempel-Ziv algorithm'),
+            ('off', 'disable image compression')
+        ],
+        help="""
+Configure the SPICE image compression (lossless).
+"""),
+    cfg.StrOpt('jpeg_compression',
+        advanced=True,
+        choices=[
+            ('auto', 'enable JPEG image compression automatically'),
+            ('never', 'disable JPEG image compression'),
+            ('always', 'enable JPEG image compression')
+        ],
+        help="""
+Configure the SPICE wan image compression (lossy for slow links).
+"""),
+    cfg.StrOpt('zlib_compression',
+        advanced=True,
+        choices=[
+            ('auto', 'enable zlib image compression automatically'),
+            ('never', 'disable zlib image compression'),
+            ('always', 'enable zlib image compression')
+        ],
+        help="""
+Configure the SPICE wan image compression (lossless for slow links).
+"""),
+    cfg.BoolOpt('playback_compression',
+        advanced=True,
+        help="""
+Enable the SPICE audio stream compression (using celt).
+"""),
+    cfg.StrOpt('streaming_mode',
+        advanced=True,
+        choices=[
+            ('filter', 'SPICE server adds additional filters to decide if '
+             'video streaming should be activated'),
+            ('all', 'any fast-refreshing window can be encoded into a video '
+             'stream'),
+            ('off', 'no video detection and (lossy) compression is performed')
+        ],
+        help="""
+Configure the SPICE video stream detection and (lossy) compression.
 """),
     cfg.URIOpt('html5proxy_base_url',
         default='http://127.0.0.1:6082/spice_auto.html',
@@ -98,7 +151,7 @@ running. This service is typically launched on the controller node.
 
 Possible values:
 
-* Must be a valid URL of the form:  ``http://host:port/spice_auto.html``
+* Must be a valid URL of the form: ``http://host:port/spice_auto.html``
   where host is the node running ``nova-spicehtml5proxy`` and the port is
   typically 6082. Consider not using default value as it is not well defined
   for any real deployment.
@@ -108,6 +161,22 @@ Related options:
 * This option depends on ``html5proxy_host`` and ``html5proxy_port`` options.
   The access URL returned by the compute node must have the host
   and port where the ``nova-spicehtml5proxy`` service is listening.
+"""),
+    cfg.URIOpt('spice_direct_proxy_base_url',
+        default='http://127.0.0.1:13002/nova',
+        help="""
+Location of a SPICE protocol native console proxy.
+
+A user can retrieve a virt-viewer style .vv connection configuration file by
+accessing this URL with the attached token when a console is created.
+
+Possible values:
+
+* Must be a valid URL of the form: ``http://host:port/nova`` where host is the
+  node running the SPICE protocol native proxy and the port is typically 13002.
+  Note that the port component is optional if you are using the default port
+  for HTTP or HTTPS. Consider not using the default value as it is not well
+  defined for any real deployment.
 """),
     cfg.StrOpt('server_listen',
         default='127.0.0.1',
@@ -141,6 +210,23 @@ Related options:
 * This option depends on the ``server_listen`` option.
   The proxy client must be able to access the address specified in
   ``server_listen`` using the value of this option.
+"""),
+    cfg.BoolOpt('require_secure',
+        default=False,
+        help="""
+Whether to require secure TLS connections to SPICE consoles.
+
+If you're providing direct access to SPICE consoles instead of using the HTML5
+proxy, you may wish those connections to be encrypted. If so, set this value to
+True.
+
+Note that use of secure consoles requires that you setup TLS certificates on
+each hypervisor.
+
+Possible values:
+
+* False: console traffic is not encrypted.
+* True: console traffic is required to be protected by TLS.
 """),
 ]
 
