@@ -15,7 +15,6 @@ from oslo_db.sqlalchemy import models
 from oslo_log import log as logging
 import sqlalchemy as sa
 import sqlalchemy.dialects.mysql
-from sqlalchemy.ext import declarative
 from sqlalchemy import orm
 from sqlalchemy import schema
 
@@ -24,11 +23,45 @@ from nova.db import types
 LOG = logging.getLogger(__name__)
 
 
+# NOTE(stephenfin): This is a list of fields that have been removed from
+# various SQLAlchemy models but which still exist in the underlying tables. Our
+# upgrade policy dictates that we remove fields from models at least one cycle
+# before we remove the column from the underlying table. Not doing so would
+# prevent us from applying the new database schema before rolling out any of
+# the new code since the old code could attempt to access data in the removed
+# columns. Alembic identifies this temporary mismatch between the models and
+# underlying tables and attempts to resolve it. Tell it instead to ignore these
+# until we're ready to remove them ourselves.
+REMOVED_COLUMNS = []
+
+# NOTE(stephenfin): A list of foreign key constraints that were removed when
+# the column they were covering was removed.
+REMOVED_FKEYS = []
+
+# NOTE(stephenfin): A list of entire models that have been removed.
+REMOVED_TABLES = {
+    # Tables that were moved the placement database in Train. The
+    # models were removed in Y and the tables can be dropped in Z or
+    # later
+    'allocations',
+    'consumers',
+    'inventories',
+    'placement_aggregates',
+    'projects',
+    'resource_classes',
+    'resource_provider_aggregates',
+    'resource_provider_traits',
+    'resource_providers',
+    'traits',
+    'users',
+}
+
+
 class _NovaAPIBase(models.ModelBase, models.TimestampMixin):
     pass
 
 
-BASE = declarative.declarative_base(cls=_NovaAPIBase)
+BASE = orm.declarative_base(cls=_NovaAPIBase)
 
 
 class AggregateHost(BASE):
@@ -113,11 +146,15 @@ class CellMapping(BASE):
     transport_url = sa.Column(sa.Text())
     database_connection = sa.Column(sa.Text())
     disabled = sa.Column(sa.Boolean, default=False)
+
     host_mapping = orm.relationship(
         'HostMapping',
-        backref=orm.backref('cell_mapping', uselist=False),
-        foreign_keys=id,
-        primaryjoin='CellMapping.id == HostMapping.cell_id')
+        back_populates='cell_mapping',
+    )
+    instance_mapping = orm.relationship(
+        'InstanceMapping',
+        back_populates='cell_mapping',
+    )
 
 
 class InstanceMapping(BASE):
@@ -144,11 +181,11 @@ class InstanceMapping(BASE):
     # transition period first.
     user_id = sa.Column(sa.String(255), nullable=True)
     queued_for_delete = sa.Column(sa.Boolean)
+
     cell_mapping = orm.relationship(
         'CellMapping',
-        backref=orm.backref('instance_mapping', uselist=False),
-        foreign_keys=cell_id,
-        primaryjoin='InstanceMapping.cell_id == CellMapping.id')
+        back_populates='instance_mapping',
+    )
 
 
 class HostMapping(BASE):
@@ -164,6 +201,11 @@ class HostMapping(BASE):
         sa.Integer, sa.ForeignKey('cell_mappings.id'), nullable=False)
     host = sa.Column(sa.String(255), nullable=False)
 
+    cell_mapping = orm.relationship(
+        'CellMapping',
+        back_populates='host_mapping',
+    )
+
 
 class RequestSpec(BASE):
     """Represents the information passed to the scheduler."""
@@ -201,6 +243,9 @@ class Flavors(BASE):
     is_public = sa.Column(sa.Boolean, default=True)
     description = sa.Column(sa.Text)
 
+    extra_specs = orm.relationship('FlavorExtraSpecs', back_populates='flavor')
+    projects = orm.relationship('FlavorProjects', back_populates='flavor')
+
 
 class FlavorExtraSpecs(BASE):
     """Represents additional specs as key/value pairs for a flavor"""
@@ -217,10 +262,8 @@ class FlavorExtraSpecs(BASE):
     value = sa.Column(sa.String(255))
     flavor_id = sa.Column(
         sa.Integer, sa.ForeignKey('flavors.id'), nullable=False)
-    flavor = orm.relationship(
-        Flavors, backref='extra_specs',
-        foreign_keys=flavor_id,
-        primaryjoin='FlavorExtraSpecs.flavor_id == Flavors.id')
+
+    flavor = orm.relationship(Flavors, back_populates='extra_specs')
 
 
 class FlavorProjects(BASE):
@@ -233,10 +276,8 @@ class FlavorProjects(BASE):
     flavor_id = sa.Column(
         sa.Integer, sa.ForeignKey('flavors.id'), nullable=False)
     project_id = sa.Column(sa.String(255), nullable=False)
-    flavor = orm.relationship(
-        Flavors, backref='projects',
-        foreign_keys=flavor_id,
-        primaryjoin='FlavorProjects.flavor_id == Flavors.id')
+
+    flavor = orm.relationship(Flavors, back_populates='projects')
 
 
 class BuildRequest(BASE):
@@ -257,13 +298,6 @@ class BuildRequest(BASE):
     instance = sa.Column(types.MediumText())
     block_device_mappings = sa.Column(types.MediumText())
     tags = sa.Column(sa.Text())
-    # TODO(alaski): Drop these from the db in Ocata
-    # columns_to_drop = ['request_spec_id', 'user_id', 'display_name',
-    #         'instance_metadata', 'progress', 'vm_state', 'task_state',
-    #         'image_ref', 'access_ip_v4', 'access_ip_v6', 'info_cache',
-    #         'security_groups', 'config_drive', 'key_name', 'locked_by',
-    #         'reservation_id', 'launch_index', 'hostname', 'kernel_id',
-    #         'ramdisk_id', 'root_device_name', 'user_data']
 
 
 class KeyPair(BASE):
@@ -284,141 +318,6 @@ class KeyPair(BASE):
         nullable=False, server_default='ssh')
 
 
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class ResourceClass(BASE):
-    """Represents the type of resource for an inventory or allocation."""
-    __tablename__ = 'resource_classes'
-    __table_args__ = (
-        schema.UniqueConstraint("name", name="uniq_resource_classes0name"),
-    )
-
-    id = sa.Column(sa.Integer, primary_key=True, nullable=False)
-    name = sa.Column(sa.String(255), nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class ResourceProvider(BASE):
-    """Represents a mapping to a providers of resources."""
-
-    __tablename__ = "resource_providers"
-    __table_args__ = (
-        sa.Index('resource_providers_uuid_idx', 'uuid'),
-        schema.UniqueConstraint('uuid', name='uniq_resource_providers0uuid'),
-        sa.Index('resource_providers_name_idx', 'name'),
-        sa.Index(
-            'resource_providers_root_provider_id_idx', 'root_provider_id'),
-        sa.Index(
-            'resource_providers_parent_provider_id_idx', 'parent_provider_id'),
-        schema.UniqueConstraint(
-            'name', name='uniq_resource_providers0name')
-    )
-
-    id = sa.Column(sa.Integer, primary_key=True, nullable=False)
-    uuid = sa.Column(sa.String(36), nullable=False)
-    name = sa.Column(sa.Unicode(200), nullable=True)
-    generation = sa.Column(sa.Integer, default=0)
-    # Represents the root of the "tree" that the provider belongs to
-    root_provider_id = sa.Column(
-        sa.Integer, sa.ForeignKey('resource_providers.id'), nullable=True)
-    # The immediate parent provider of this provider, or NULL if there is no
-    # parent. If parent_provider_id == NULL then root_provider_id == id
-    parent_provider_id = sa.Column(
-        sa.Integer, sa.ForeignKey('resource_providers.id'), nullable=True)
-    # TODO(stephenfin): Drop these from the db at some point
-    # columns_to_drop = ['can_host']
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class Inventory(BASE):
-    """Represents a quantity of available resource."""
-
-    __tablename__ = "inventories"
-    __table_args__ = (
-        sa.Index(
-            'inventories_resource_provider_id_idx', 'resource_provider_id'),
-        sa.Index(
-            'inventories_resource_class_id_idx', 'resource_class_id'),
-        sa.Index(
-            'inventories_resource_provider_resource_class_idx',
-            'resource_provider_id',
-            'resource_class_id',
-        ),
-        schema.UniqueConstraint(
-            'resource_provider_id',
-            'resource_class_id',
-            name='uniq_inventories0resource_provider_resource_class'
-        ),
-    )
-
-    id = sa.Column(sa.Integer, primary_key=True, nullable=False)
-    resource_provider_id = sa.Column(sa.Integer, nullable=False)
-    resource_class_id = sa.Column(sa.Integer, nullable=False)
-    total = sa.Column(sa.Integer, nullable=False)
-    reserved = sa.Column(sa.Integer, nullable=False)
-    min_unit = sa.Column(sa.Integer, nullable=False)
-    max_unit = sa.Column(sa.Integer, nullable=False)
-    step_size = sa.Column(sa.Integer, nullable=False)
-    allocation_ratio = sa.Column(sa.Float, nullable=False)
-    resource_provider = orm.relationship(
-        "ResourceProvider",
-        primaryjoin='Inventory.resource_provider_id == ResourceProvider.id',
-        foreign_keys=resource_provider_id)
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class Allocation(BASE):
-    """A use of inventory."""
-
-    __tablename__ = "allocations"
-    __table_args__ = (
-        sa.Index(
-            'allocations_resource_provider_class_used_idx',
-            'resource_provider_id',
-            'resource_class_id',
-            'used',
-        ),
-        sa.Index('allocations_resource_class_id_idx', 'resource_class_id'),
-        sa.Index('allocations_consumer_id_idx', 'consumer_id')
-    )
-
-    id = sa.Column(sa.Integer, primary_key=True, nullable=False)
-    resource_provider_id = sa.Column(sa.Integer, nullable=False)
-    consumer_id = sa.Column(sa.String(36), nullable=False)
-    resource_class_id = sa.Column(sa.Integer, nullable=False)
-    used = sa.Column(sa.Integer, nullable=False)
-    resource_provider = orm.relationship(
-        "ResourceProvider",
-        primaryjoin='Allocation.resource_provider_id == ResourceProvider.id',
-        foreign_keys=resource_provider_id)
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class ResourceProviderAggregate(BASE):
-    """Associate a resource provider with an aggregate."""
-
-    __tablename__ = 'resource_provider_aggregates'
-    __table_args__ = (
-        sa.Index(
-            'resource_provider_aggregates_aggregate_id_idx', 'aggregate_id'),
-    )
-
-    resource_provider_id = sa.Column(
-        sa.Integer, primary_key=True, nullable=False)
-    aggregate_id = sa.Column(sa.Integer, primary_key=True, nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class PlacementAggregate(BASE):
-    """A grouping of resource providers."""
-    __tablename__ = 'placement_aggregates'
-    __table_args__ = (
-        schema.UniqueConstraint("uuid", name="uniq_placement_aggregates0uuid"),
-    )
-
-    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
-    uuid = sa.Column(sa.String(36), index=True)
-
-
 class InstanceGroupMember(BASE):
     """Represents the members for an instance group."""
     __tablename__ = 'instance_group_member'
@@ -462,12 +361,9 @@ class InstanceGroup(BASE):
     project_id = sa.Column(sa.String(255))
     uuid = sa.Column(sa.String(36), nullable=False)
     name = sa.Column(sa.String(255))
-    _policies = orm.relationship(
-        InstanceGroupPolicy,
-        primaryjoin='InstanceGroup.id == InstanceGroupPolicy.group_id')
-    _members = orm.relationship(
-        InstanceGroupMember,
-        primaryjoin='InstanceGroup.id == InstanceGroupMember.group_id')
+
+    _policies = orm.relationship(InstanceGroupPolicy)
+    _members = orm.relationship(InstanceGroupMember)
 
     @property
     def policy(self):
@@ -595,98 +491,5 @@ class Reservation(BASE):
     resource = sa.Column(sa.String(255))
     delta = sa.Column(sa.Integer, nullable=False)
     expire = sa.Column(sa.DateTime)
-    usage = orm.relationship(
-        "QuotaUsage",
-        foreign_keys=usage_id,
-        primaryjoin='Reservation.usage_id == QuotaUsage.id')
 
-
-class Trait(BASE):
-    """Represents a trait."""
-
-    __tablename__ = "traits"
-    __table_args__ = (
-        schema.UniqueConstraint('name', name='uniq_traits0name'),
-    )
-
-    id = sa.Column(
-        sa.Integer, primary_key=True, nullable=False, autoincrement=True)
-    name = sa.Column(sa.Unicode(255), nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's now unused post-placement split
-class ResourceProviderTrait(BASE):
-    """Represents the relationship between traits and resource provider"""
-
-    __tablename__ = "resource_provider_traits"
-    __table_args__ = (
-        sa.Index('resource_provider_traits_resource_provider_trait_idx',
-              'resource_provider_id', 'trait_id'),
-    )
-
-    trait_id = sa.Column(
-        sa.Integer, sa.ForeignKey('traits.id'), primary_key=True,
-        nullable=False)
-    resource_provider_id = sa.Column(
-        sa.Integer,
-        sa.ForeignKey('resource_providers.id'),
-        primary_key=True,
-        nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's unused
-class Project(BASE):
-    """The project is the Keystone project."""
-
-    __tablename__ = 'projects'
-    __table_args__ = (
-        schema.UniqueConstraint(
-            'external_id',
-            name='uniq_projects0external_id',
-        ),
-    )
-
-    id = sa.Column(
-        sa.Integer, primary_key=True, nullable=False, autoincrement=True)
-    external_id = sa.Column(sa.String(255), nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's unused
-class User(BASE):
-    """The user is the Keystone user."""
-
-    __tablename__ = 'users'
-    __table_args__ = (
-        schema.UniqueConstraint('external_id', name='uniq_users0external_id'),
-    )
-
-    id = sa.Column(
-        sa.Integer, primary_key=True, nullable=False, autoincrement=True)
-    external_id = sa.Column(sa.String(255), nullable=False)
-
-
-# TODO(stephenfin): Remove this as it's unused
-class Consumer(BASE):
-    """Represents a resource consumer."""
-
-    __tablename__ = 'consumers'
-    __table_args__ = (
-        sa.Index('consumers_project_id_uuid_idx', 'project_id', 'uuid'),
-        sa.Index(
-            'consumers_project_id_user_id_uuid_idx',
-            'project_id',
-            'user_id',
-            'uuid',
-        ),
-        schema.UniqueConstraint('uuid', name='uniq_consumers0uuid'),
-    )
-
-    id = sa.Column(
-        sa.Integer, primary_key=True, nullable=False, autoincrement=True)
-    uuid = sa.Column(sa.String(36), nullable=False)
-    project_id = sa.Column(sa.Integer, nullable=False)
-    user_id = sa.Column(sa.Integer, nullable=False)
-    # FIXME(mriedem): Change this to server_default=text("0") to match the
-    # 059_add_consumer_generation script once bug 1776527 is fixed.
-    generation = sa.Column(
-        sa.Integer, nullable=False, server_default="0", default=0)
+    usage = orm.relationship('QuotaUsage')
