@@ -2661,3 +2661,8 @@ class EphemeralEncryptionCleanupFailed(NovaException):
 
 class HostConflict(Exception):
     pass
+
+
+class InstanceEventTimeout(Exception):
+    """A custom timeout exception to replace eventlet.timeout.Timeout."""
+    pass
