@@ -24,11 +24,15 @@ def set_defaults():
                        'X-Roles',
                        'X-Service-Catalog',
                        'X-User-Id',
-                       'X-Tenant-Id'],
+                       'X-Tenant-Id',
+                       'X-OpenStack-Nova-API-Version',
+                       'OpenStack-API-Version'],
         expose_headers=['X-Auth-Token',
                         'X-Openstack-Request-Id',
                         'X-Subject-Token',
-                        'X-Service-Token'],
+                        'X-Service-Token',
+                        'X-OpenStack-Nova-API-Version',
+                        'OpenStack-API-Version'],
         allow_methods=['GET',
                        'PUT',
                        'POST',
