@@ -22,15 +22,28 @@ POLICY_ROOT = 'os_compute_api:os-assisted-volume-snapshots:%s'
 
 
 assisted_volume_snapshots_policies = [
-    policy.RuleDefault(
+    policy.DocumentedRuleDefault(
         name=POLICY_ROOT % 'create',
-        check_str=base.RULE_ADMIN_API),
-    policy.RuleDefault(
+        check_str=base.SERVICE_ROLE,
+        description="Create an assisted volume snapshot",
+        operations=[
+            {
+                'path': '/os-assisted-volume-snapshots',
+                'method': 'POST'
+            }
+        ],
+        scope_types=['project']),
+    policy.DocumentedRuleDefault(
         name=POLICY_ROOT % 'delete',
-        check_str=base.RULE_ADMIN_API),
-    policy.RuleDefault(
-        name=POLICY_ROOT % 'discoverable',
-        check_str=base.RULE_ANY),
+        check_str=base.SERVICE_ROLE,
+        description="Delete an assisted volume snapshot",
+        operations=[
+            {
+                'path': '/os-assisted-volume-snapshots/{snapshot_id}',
+                'method': 'DELETE'
+            }
+        ],
+        scope_types=['project']),
 ]
 
 
