@@ -142,8 +142,6 @@ def map_az_to_placement_aggregate(ctxt, request_spec):
     This will modify request_spec to request hosts in an aggregate that
     matches the desired AZ of the user's request.
     """
-    if not CONF.scheduler.query_placement_for_availability_zone:
-        return False
 
     az_hint = request_spec.availability_zone
     if not az_hint:
@@ -273,6 +271,22 @@ def accelerators_filter(ctxt, request_spec):
     return True
 
 
+@trace_request_filter
+def packed_virtqueue_filter(ctxt, request_spec):
+    """Allow only compute nodes with Packed virtqueue.
+
+    This filter retains only nodes whose compute manager published the
+    COMPUTE_NET_VIRTIO_PACKED trait, thus indicates virtqueue packed feature.
+    """
+    trait_name = os_traits.COMPUTE_NET_VIRTIO_PACKED
+    if (hardware.get_packed_virtqueue_constraint(request_spec.flavor,
+                                                 request_spec.image)):
+        request_spec.root_required.add(trait_name)
+        LOG.debug('virtqueue_filter request filter added required '
+                  'trait %s', trait_name)
+    return True
+
+
 @trace_request_filter
 def routed_networks_filter(
     ctxt: nova_context.RequestContext,
@@ -430,6 +444,27 @@ def ephemeral_encryption_filter(
     return True
 
 
+@trace_request_filter
+def virtio_sound_filter(
+    ctxt: nova_context.RequestContext,
+    request_spec: 'objects.RequestSpec'
+) -> bool:
+    """Filter out hosts which do not support virtio sound devices
+
+    This filter will only retain compute node resource providers that support
+    virtio sound devices.
+    """
+    # Skip if the instance does not request a virtio sound device
+    model = hardware.get_sound_model(request_spec.flavor, request_spec.image)
+    if model != objects.fields.SoundModelType.VIRTIO:
+        LOG.debug('virtio_sound_filter skipped')
+        return False
+
+    request_spec.root_required.add(os_traits.COMPUTE_SOUND_MODEL_VIRTIO)
+    LOG.debug('virtio_sound_filter added trait COMPUTE_SOUND_MODEL_VIRTIO')
+    return True
+
+
 ALL_REQUEST_FILTERS = [
     require_tenant_aggregate,
     map_az_to_placement_aggregate,
@@ -438,9 +473,11 @@ ALL_REQUEST_FILTERS = [
     isolate_aggregates,
     transform_image_metadata,
     accelerators_filter,
+    packed_virtqueue_filter,
     routed_networks_filter,
     remote_managed_ports_filter,
     ephemeral_encryption_filter,
+    virtio_sound_filter
 ]
 
 
