@@ -18,7 +18,6 @@ import testscenarios
 
 import nova.conf
 from nova.tests import fixtures
-from nova.tests.functional import api_paste_fixture
 from nova.tests.functional import api_samples_test_base
 
 CONF = nova.conf.CONF
@@ -56,7 +55,6 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
                            api_samples_test_base.ApiSampleTestBase):
     SUPPORTS_CELLS = False
 
-    api_major_version = 'v2'
     # any additional fixtures needed for this scenario
     _additional_fixtures = []
     sample_dir = None
@@ -67,22 +65,19 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
     # correctly constructed.
     USE_PROJECT_ID = True
     # Availability zones for the API samples tests. Can be overridden by
-    # sub-classes. If set, the AvailabilityZoneFilter is not used.
+    # sub-classes.
     availability_zones = ['us-west']
 
     scenarios = [
         # test v2 with the v2.1 compatibility stack
-        ('v2', {
-            'api_major_version': 'v2'}),
+        ('v2', {'api_major_version': 'v2'}),
         # test v2.1 base microversion
-        ('v2_1', {
-            'api_major_version': 'v2.1'}),
+        ('v2_1', {'api_major_version': 'v2.1'}),
         # test v2.18 code without project id
-        ('v2_1_noproject_id', {
-            'api_major_version': 'v2.1',
-            'USE_PROJECT_ID': False,
-            '_additional_fixtures': [
-                api_paste_fixture.ApiPasteNoProjectId]})
+        (
+            'v2_1_noproject_id',
+            {'api_major_version': 'v2.1', 'USE_PROJECT_ID': False},
+        ),
     ]
 
     def setUp(self):
@@ -122,17 +117,3 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
 
     def _setup_services(self):
         pass
-
-    def _setup_scheduler_service(self):
-        """Overrides _IntegratedTestBase._setup_scheduler_service to filter
-        out the AvailabilityZoneFilter prior to starting the scheduler.
-        """
-        if self.availability_zones:
-            # The test is using fake zones so disable the
-            # AvailabilityZoneFilter which is otherwise enabled by default.
-            enabled_filters = CONF.filter_scheduler.enabled_filters
-            if 'AvailabilityZoneFilter' in enabled_filters:
-                enabled_filters.remove('AvailabilityZoneFilter')
-                self.flags(enabled_filters=enabled_filters,
-                           group='filter_scheduler')
-        return super(ApiSampleTestBaseV21, self)._setup_scheduler_service()
