@@ -12,9 +12,9 @@
 
 import copy
 import os
+from unittest import mock
 
 import fixtures
-import mock
 import os_resource_classes as orc
 import os_traits
 from oslo_utils.fixture import uuidsentinel as uuids
@@ -248,6 +248,7 @@ class IronicResourceTrackerTest(test.TestCase):
                 'numa_topology': None,
                 'resource_class': None,  # Act like admin hasn't set yet...
                 'stats': stats,
+                'uuid': str(getattr(uuids, nodename)),
             }
             self.rt.update_available_resource(self.ctx, nodename)
 
