@@ -15,7 +15,7 @@ from oslo_utils.fixture import uuidsentinel
 
 import nova.conf
 from nova import context
-from nova.db import api as db
+from nova.db.main import api as db
 from nova import objects
 from nova.objects import compute_node
 from nova.objects import fields as obj_fields
@@ -267,7 +267,7 @@ class ComputeNodeTestCase(test.TestCase):
         self.assertEqual(res, (1, 1))
 
         # the ratio is refreshed to CONF.initial_xxx_allocation_ratio
-        # beacause CONF.xxx_allocation_ratio is None
+        # because CONF.xxx_allocation_ratio is None
         cns = db.compute_node_get_all(self.context)
         # the ratio is refreshed to CONF.xxx_allocation_ratio
         for cn in cns:
