@@ -411,7 +411,7 @@ class InstanceHelperMixin:
             'is_public': False,
             'container_format': 'raw',
             'disk_format': 'raw',
-            'size': '25165824',
+            'size': 25165824,
             'min_ram': 0,
             'min_disk': 0,
             'protected': False,
@@ -740,8 +740,9 @@ class InstanceHelperMixin:
     def _create_server_boot_from_volume(self, image_args=None,
                                         flavor_id=None, networks=None):
         bfv_image_id = uuids.bfv_image_uuid
-        timestamp = datetime.datetime(2011, 1, 1, 1, 2, 3)
-
+        timestamp = datetime.datetime(
+            2011, 1, 1, 1, 2, 3, tzinfo=datetime.timezone.utc
+        )
         image = {
             'id': bfv_image_id,
             'name': 'fake_image_name',
@@ -752,7 +753,8 @@ class InstanceHelperMixin:
             'status': 'active',
             'container_format': 'raw',
             'disk_format': 'raw',
-            'min_disk': 0
+            'min_disk': 0,
+            'size': 74185822,
         }
         if image_args:
             image.update(image_args)
@@ -1311,7 +1313,7 @@ class PlacementInstanceHelperMixin(InstanceHelperMixin, PlacementHelperMixin):
         given flavor (assumes a single instance on the hypervisor).
 
         :param compute_node_uuid: UUID of the ComputeNode to check.
-        :param flavor: "flavor" entry dict from from GET /flavors/{flavor_id}
+        :param flavor: "flavor" entry dict from GET /flavors/{flavor_id}
         :param volume_backed: True if the flavor is used with a volume-backed
             server, False otherwise.
         """
