@@ -19,7 +19,6 @@ import os_resource_classes as orc
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import uuidutils
-from oslo_utils import versionutils
 
 from nova.compute import instance_actions
 import nova.conf
@@ -36,9 +35,7 @@ LOG = logging.getLogger(__name__)
 
 
 class VGPUTestBase(base.ServersTestBase):
-
     # We want to target some hosts for some created instances
-    api_major_version = 'v2.1'
     microversion = 'latest'
     ADMIN_API = True
 
@@ -56,16 +53,10 @@ class VGPUTestBase(base.ServersTestBase):
             'used': 44,
             'free': 84,
         }
-        # Persistent mdevs in libvirt >= 7.3.0
-        if self.FAKE_LIBVIRT_VERSION < versionutils.convert_version_to_int(
-                libvirt_driver.MIN_LIBVIRT_PERSISTENT_MDEV):
-            create_mdev_str = 'nova.privsep.libvirt.create_mdev'
-        else:
-            create_mdev_str = (
-                'nova.virt.libvirt.driver.LibvirtDriver._create_mdev')
-            self._create_mdev = self._create_mdev_7_3
         self.useFixture(
-            fixtures.MockPatch(create_mdev_str, side_effect=self._create_mdev))
+            fixtures.MockPatch(
+                'nova.virt.libvirt.driver.LibvirtDriver._create_mdev',
+                side_effect=self._create_mdev))
 
         # for the sake of resizing, we need to patch the two methods below
         self.useFixture(fixtures.MockPatch(
@@ -104,25 +95,7 @@ class VGPUTestBase(base.ServersTestBase):
     def libvirt2pci_address(self, dev_name):
         return "{}:{}:{}.{}".format(*dev_name[4:].split('_'))
 
-    def _create_mdev(self, physical_device, mdev_type, uuid=None):
-        # We need to fake the newly created sysfs object by adding a new
-        # FakeMdevDevice in the existing persisted Connection object so
-        # when asking to get the existing mdevs, we would see it.
-        if not uuid:
-            uuid = uuidutils.generate_uuid()
-        mdev_name = libvirt_utils.mdev_uuid2name(uuid)
-        libvirt_parent = self.pci2libvirt_address(physical_device)
-        # Here, we get the right compute thanks by the self.current_host that
-        # was modified just before
-        connection = self.computes[
-            self._current_host].driver._host.get_connection()
-        connection.mdev_info.devices.update(
-            {mdev_name: fakelibvirt.FakeMdevDevice(dev_name=mdev_name,
-                                                   type_id=mdev_type,
-                                                   parent=libvirt_parent)})
-        return uuid
-
-    def _create_mdev_7_3(self, dev_name, mdev_type, uuid=None):
+    def _create_mdev(self, dev_name, mdev_type, uuid=None):
         # We need to fake the newly created sysfs object by adding a new
         # FakeMdevDevice in the existing persisted Connection object so
         # when asking to get the existing mdevs, we would see it.
