@@ -17,14 +17,13 @@ import datetime
 from nova import test
 from nova.tests import fixtures as nova_fixtures
 from nova.tests.functional.api import client as api_client
-from nova.tests.unit import policy_fixture
 
 
 class TestServerGet(test.TestCase):
 
     def setUp(self):
         super(TestServerGet, self).setUp()
-        self.useFixture(policy_fixture.RealPolicyFixture())
+        self.useFixture(nova_fixtures.RealPolicyFixture())
         self.useFixture(nova_fixtures.NeutronFixture(self))
         self.glance = self.useFixture(nova_fixtures.GlanceFixture(self))
         api_fixture = self.useFixture(nova_fixtures.OSAPIFixture(
@@ -45,7 +44,7 @@ class TestServerGet(test.TestCase):
                  'is_public': False,
                  'container_format': 'raw',
                  'disk_format': 'raw',
-                 'size': '25165824',
+                 'size': 25165824,
                  'properties': {'kernel_id': 'nokernel',
                                 'ramdisk_id': 'nokernel',
                                 'architecture': 'x64'}}
