@@ -13,8 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-import six
+from unittest import mock
+
 from webob import exc
 
 from nova.api.openstack import common
@@ -48,7 +48,9 @@ port_data1 = {
     "admin_state_up": True,
     "status": "ACTIVE",
     "mac_address": "aa:aa:aa:aa:aa:aa",
-    "fixed_ips": ["10.0.1.2"],
+    "fixed_ips": [
+        {"ip_address": "10.0.1.2", "subnet_id": FAKE_UUID2},
+    ],
     "device_id": FAKE_UUID1,
 }
 
@@ -58,7 +60,9 @@ port_data2 = {
     "admin_state_up": True,
     "status": "ACTIVE",
     "mac_address": "bb:bb:bb:bb:bb:bb",
-    "fixed_ips": ["10.0.2.2"],
+    "fixed_ips": [
+        {"ip_address": "10.0.2.2", "subnet_id": FAKE_UUID2},
+    ],
     "device_id": FAKE_UUID1,
 }
 
@@ -68,7 +72,9 @@ port_data3 = {
     "admin_state_up": True,
     "status": "ACTIVE",
     "mac_address": "bb:bb:bb:bb:bb:bb",
-    "fixed_ips": ["10.0.2.2"],
+    "fixed_ips": [
+        {"ip_address": "10.0.3.2", "subnet_id": FAKE_UUID2},
+    ],
     "device_id": '',
 }
 
@@ -188,11 +194,11 @@ class InterfaceAttachTestsV21(test.NoDBTestCase):
                                return_value=inst) as mock_get_instance:
             result = self.attachments.delete(self.req, FAKE_UUID1,
                                              FAKE_PORT_ID1)
-            # NOTE: on v2.1, http status code is set as wsgi_code of API
+            # NOTE: on v2.1, http status code is set as wsgi_codes of API
             # method instead of status_int in a response object.
             if isinstance(self.attachments,
                           attach_interfaces_v21.InterfaceAttachmentController):
-                status_int = self.attachments.delete.wsgi_code
+                status_int = self.attachments.delete.wsgi_codes(self.req)
             else:
                 status_int = result.status_int
             self.assertEqual(202, status_int)
@@ -253,6 +259,23 @@ class InterfaceAttachTestsV21(test.NoDBTestCase):
         self.assertRaises(exc.HTTPBadRequest, self.attachments.create,
                           self.req, FAKE_UUID1, body=body)
 
+    @mock.patch.object(
+        compute_api.API, 'attach_interface',
+        side_effect=exception.OperationNotSupportedForVDPAInterface(
+            instance_uuid=FAKE_UUID1, operation='foo'))
+    def test_interface_vdpa_interface_not_supported(self, mock_attach):
+        body = {'interfaceAttachment': {'net_id': FAKE_NET_ID2}}
+        self.assertRaises(exc.HTTPBadRequest, self.attachments.create,
+                          self.req, FAKE_UUID1, body=body)
+
+    @mock.patch.object(
+        compute_api.API, 'detach_interface',
+        side_effect=exception.OperationNotSupportedForVDPAInterface(
+            instance_uuid=FAKE_UUID1, operation='foo'))
+    def test_detach_interface_vdpa_interface_not_supported(self, mock_detach):
+        self.assertRaises(exc.HTTPBadRequest, self.attachments.delete,
+                          self.req, FAKE_UUID1, FAKE_NET_ID1)
+
     def test_attach_interface_with_network_id(self):
         self.stub_out('nova.compute.api.API.attach_interface',
                       fake_attach_interface)
@@ -325,7 +348,7 @@ class InterfaceAttachTestsV21(test.NoDBTestCase):
             ex = self.assertRaises(
                 exc.HTTPForbidden, self.attachments.create,
                 self.req, FAKE_UUID1, body=body)
-        self.assertIn('Maximum number of ports exceeded', six.text_type(ex))
+        self.assertIn('Maximum number of ports exceeded', str(ex))
 
     def test_detach_interface_with_invalid_state(self):
         def fake_detach_interface_invalid_state(*args, **kwargs):
@@ -512,6 +535,13 @@ class InterfaceAttachTestsV249(test.NoDBTestCase):
     def setUp(self):
         super(InterfaceAttachTestsV249, self).setUp()
         self.attachments = self.controller_cls()
+        show_port_patch = mock.patch.object(self.attachments.network_api,
+                                            'show_port', fake_show_port)
+        show_port_patch.start()
+        self.addCleanup(show_port_patch.stop)
+        self.stub_out('nova.compute.api.API.attach_interface',
+                      fake_attach_interface)
+
         self.req = fakes.HTTPRequest.blank('', version='2.49')
 
     def test_tagged_interface_attach_invalid_tag_comma(self):
@@ -533,17 +563,18 @@ class InterfaceAttachTestsV249(test.NoDBTestCase):
         self.assertRaises(exception.ValidationError, self.attachments.create,
                           self.req, FAKE_UUID1, body=body)
 
-    @mock.patch('nova.compute.api.API.attach_interface')
     @mock.patch('nova.compute.api.API.get', fake_get_instance)
-    def test_tagged_interface_attach_valid_tag(self, _):
-        body = {'interfaceAttachment': {'net_id': FAKE_NET_ID2,
+    def test_tagged_interface_attach_valid_tag(self):
+        body = {'interfaceAttachment': {'net_id': FAKE_NET_ID1,
                                         'tag': 'foo'}}
-        with mock.patch.object(self.attachments, 'show'):
+        with mock.patch.object(self.attachments.network_api, 'show_port',
+                               fake_show_port):
             self.attachments.create(self.req, FAKE_UUID1, body=body)
 
 
 class InterfaceAttachTestsV270(test.NoDBTestCase):
     """os-interface API tests for microversion 2.70"""
+
     def setUp(self):
         super(InterfaceAttachTestsV270, self).setUp()
         self.attachments = (
