@@ -14,8 +14,8 @@
 #    under the License.
 
 import datetime
+from unittest import mock
 
-import mock
 from oslo_serialization import jsonutils
 
 from nova.api.openstack import compute
@@ -73,23 +73,22 @@ class DiskConfigTestCaseV21(test.TestCase):
 
         def fake_instance_create(context, inst_, session=None):
             inst = fake_instance.fake_db_instance(**{
-                    'id': 1,
-                    'uuid': AUTO_INSTANCE_UUID,
-                    'created_at': datetime.datetime(2010, 10, 10, 12, 0, 0),
-                    'updated_at': datetime.datetime(2010, 10, 10, 12, 0, 0),
-                    'progress': 0,
-                    'name': 'instance-1',  # this is a property
-                    'task_state': '',
-                    'vm_state': '',
-                    'auto_disk_config': inst_['auto_disk_config'],
-                    'security_groups': inst_['security_groups'],
-                    'instance_type': objects.Flavor.get_by_name(context,
-                                                                'm1.small'),
-                    })
+                'id': 1,
+                'uuid': AUTO_INSTANCE_UUID,
+                'created_at': datetime.datetime(2010, 10, 10, 12, 0, 0),
+                'updated_at': datetime.datetime(2010, 10, 10, 12, 0, 0),
+                'progress': 0,
+                'name': 'instance-1',  # this is a property
+                'task_state': '',
+                'vm_state': '',
+                'auto_disk_config': inst_['auto_disk_config'],
+                'security_groups': inst_['security_groups'],
+                'flavor': objects.Flavor.get_by_name(context, 'm1.small'),
+            })
 
             return inst
 
-        self.stub_out('nova.db.api.instance_create', fake_instance_create)
+        self.stub_out('nova.db.main.api.instance_create', fake_instance_create)
 
     def _set_up_app(self):
         self.app = compute.APIRouterV21()
@@ -112,7 +111,7 @@ class DiskConfigTestCaseV21(test.TestCase):
                  'is_public': False,
                  'container_format': 'ova',
                  'disk_format': 'vhd',
-                 'size': '74185822',
+                 'size': 74185822,
                  'properties': {'auto_disk_config': 'Disabled'}}
         self.image_service.create(None, image)
 
