@@ -19,8 +19,9 @@ Tests dealing with HTTP rate-limiting.
 
 from http import client as httplib
 from io import StringIO
+from unittest import mock
 
-import mock
+from oslo_limit import fixture as limit_fixture
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
 
@@ -29,6 +30,9 @@ from nova.api.openstack.compute import views
 from nova.api.openstack import wsgi
 import nova.context
 from nova import exception
+from nova.limit import local as local_limit
+from nova.limit import placement as placement_limit
+from nova import objects
 from nova.policies import limits as l_policies
 from nova import test
 from nova.tests.unit.api.openstack import fakes
@@ -209,9 +213,7 @@ class LimitsControllerTestV21(BaseLimitTestSuite):
         fake_req.get_response(self.controller)
         self.assertEqual(2, self.mock_can.call_count)
         self.mock_can.assert_called_with(
-            l_policies.OTHER_PROJECT_LIMIT_POLICY_NAME,
-            target={'project_id': 'abcd'}
-        )
+            l_policies.OTHER_PROJECT_LIMIT_POLICY_NAME)
         self.mock_get_project_quotas.assert_called_once_with(context,
             tenant_id, usages=True)
 
@@ -250,7 +252,7 @@ class LimitsControllerTestV21(BaseLimitTestSuite):
         req_get = {'tenant_id': -1}
         self._test_admin_can_fetch_used_limits_for_own_project(req_get)
 
-    def test_admin_can_fetch_used_limits_with_unkown_param(self):
+    def test_admin_can_fetch_used_limits_with_unknown_param(self):
         req_get = {'tenant_id': '123', 'unknown': 'unknown'}
         self._test_admin_can_fetch_used_limits_for_own_project(req_get)
 
@@ -455,7 +457,7 @@ class LimitsControllerTestV275(BaseLimitTestSuite):
         absolute_limits = {
             "metadata_items": 1,
         }
-        req = fakes.HTTPRequest.blank("/?unkown=fake",
+        req = fakes.HTTPRequest.blank("/?unknown=fake",
                                        version='2.74')
 
         def _get_project_quotas(context, project_id, usages=True):
@@ -467,8 +469,158 @@ class LimitsControllerTestV275(BaseLimitTestSuite):
         self.controller.index(req)
 
     def test_index_additional_query_param(self):
-        req = fakes.HTTPRequest.blank("/?unkown=fake",
+        req = fakes.HTTPRequest.blank("/?unknown=fake",
                                       version='2.75')
         self.assertRaises(
             exception.ValidationError,
             self.controller.index, req=req)
+
+
+class NoopLimitsControllerTest(test.NoDBTestCase):
+    quota_driver = "nova.quota.NoopQuotaDriver"
+
+    def setUp(self):
+        super(NoopLimitsControllerTest, self).setUp()
+        self.flags(driver=self.quota_driver, group="quota")
+        self.controller = limits_v21.LimitsController()
+        # remove policy checks
+        patcher = self.mock_can = mock.patch('nova.context.RequestContext.can')
+        self.mock_can = patcher.start()
+        self.addCleanup(patcher.stop)
+
+    def test_index_v21(self):
+        req = fakes.HTTPRequest.blank("/")
+        response = self.controller.index(req)
+        expected_response = {
+            "limits": {
+                "rate": [],
+                "absolute": {
+                    'maxImageMeta': -1,
+                    'maxPersonality': -1,
+                    'maxPersonalitySize': -1,
+                    'maxSecurityGroupRules': -1,
+                    'maxSecurityGroups': -1,
+                    'maxServerGroupMembers': -1,
+                    'maxServerGroups': -1,
+                    'maxServerMeta': -1,
+                    'maxTotalCores': -1,
+                    'maxTotalFloatingIps': -1,
+                    'maxTotalInstances': -1,
+                    'maxTotalKeypairs': -1,
+                    'maxTotalRAMSize': -1,
+                    'totalCoresUsed': -1,
+                    'totalFloatingIpsUsed': -1,
+                    'totalInstancesUsed': -1,
+                    'totalRAMUsed': -1,
+                    'totalSecurityGroupsUsed': -1,
+                    'totalServerGroupsUsed': -1,
+                },
+            },
+        }
+        self.assertEqual(expected_response, response)
+
+    def test_index_v275(self):
+        req = fakes.HTTPRequest.blank("/?tenant_id=faketenant",
+                                      version='2.75')
+        response = self.controller.index(req)
+        expected_response = {
+            "limits": {
+                "rate": [],
+                "absolute": {
+                    'maxServerGroupMembers': -1,
+                    'maxServerGroups': -1,
+                    'maxServerMeta': -1,
+                    'maxTotalCores': -1,
+                    'maxTotalInstances': -1,
+                    'maxTotalKeypairs': -1,
+                    'maxTotalRAMSize': -1,
+                    'totalCoresUsed': -1,
+                    'totalInstancesUsed': -1,
+                    'totalRAMUsed': -1,
+                    'totalServerGroupsUsed': -1,
+                },
+            },
+        }
+        self.assertEqual(expected_response, response)
+
+
+class UnifiedLimitsControllerTest(NoopLimitsControllerTest):
+    quota_driver = "nova.quota.UnifiedLimitsDriver"
+
+    def setUp(self):
+        super(UnifiedLimitsControllerTest, self).setUp()
+        reglimits = {local_limit.SERVER_METADATA_ITEMS: 128,
+                     local_limit.INJECTED_FILES: 5,
+                     local_limit.INJECTED_FILES_CONTENT: 10 * 1024,
+                     local_limit.INJECTED_FILES_PATH: 255,
+                     local_limit.KEY_PAIRS: 100,
+                     local_limit.SERVER_GROUPS: 12,
+                     local_limit.SERVER_GROUP_MEMBERS: 10}
+        self.useFixture(limit_fixture.LimitFixture(reglimits, {}))
+
+    @mock.patch.object(placement_limit, "get_legacy_counts")
+    @mock.patch.object(placement_limit, "get_legacy_project_limits")
+    @mock.patch.object(objects.InstanceGroupList, "get_counts")
+    def test_index_v21(self, mock_count, mock_proj, mock_kcount):
+        mock_proj.return_value = {"instances": 1, "cores": 2, "ram": 3}
+        mock_kcount.return_value = {"instances": 4, "cores": 5, "ram": 6}
+        mock_count.return_value = {'project': {'server_groups': 9}}
+        req = fakes.HTTPRequest.blank("/")
+        response = self.controller.index(req)
+        expected_response = {
+            "limits": {
+                "rate": [],
+                "absolute": {
+                    'maxImageMeta': 128,
+                    'maxPersonality': 5,
+                    'maxPersonalitySize': 10240,
+                    'maxSecurityGroupRules': -1,
+                    'maxSecurityGroups': -1,
+                    'maxServerGroupMembers': 10,
+                    'maxServerGroups': 12,
+                    'maxServerMeta': 128,
+                    'maxTotalCores': 2,
+                    'maxTotalFloatingIps': -1,
+                    'maxTotalInstances': 1,
+                    'maxTotalKeypairs': 100,
+                    'maxTotalRAMSize': 3,
+                    'totalCoresUsed': 5,
+                    'totalFloatingIpsUsed': 0,
+                    'totalInstancesUsed': 4,
+                    'totalRAMUsed': 6,
+                    'totalSecurityGroupsUsed': 0,
+                    'totalServerGroupsUsed': 9,
+                },
+            },
+        }
+        self.assertEqual(expected_response, response)
+
+    @mock.patch.object(placement_limit, "get_legacy_counts")
+    @mock.patch.object(placement_limit, "get_legacy_project_limits")
+    @mock.patch.object(objects.InstanceGroupList, "get_counts")
+    def test_index_v275(self, mock_count, mock_proj, mock_kcount):
+        mock_proj.return_value = {"instances": 1, "cores": 2, "ram": 3}
+        mock_kcount.return_value = {"instances": 4, "cores": 5, "ram": 6}
+        mock_count.return_value = {'project': {'server_groups': 9}}
+        req = fakes.HTTPRequest.blank("/?tenant_id=faketenant",
+                                      version='2.75')
+        response = self.controller.index(req)
+        expected_response = {
+            "limits": {
+                "rate": [],
+                "absolute": {
+                    'maxServerGroupMembers': 10,
+                    'maxServerGroups': 12,
+                    'maxServerMeta': 128,
+                    'maxTotalCores': 2,
+                    'maxTotalInstances': 1,
+                    'maxTotalKeypairs': 100,
+                    'maxTotalRAMSize': 3,
+                    'totalCoresUsed': 5,
+                    'totalInstancesUsed': 4,
+                    'totalRAMUsed': 6,
+                    'totalServerGroupsUsed': 9,
+                },
+            },
+        }
+        self.assertEqual(expected_response, response)
