@@ -16,6 +16,7 @@
 from unittest import mock
 
 import webob
+import webob.exc
 
 from nova.api.openstack import api_version_request
 from nova.api.openstack.compute import remote_consoles \
@@ -65,8 +66,8 @@ class ConsolesExtensionTestV21(test.NoDBTestCase):
         req = fakes.HTTPRequest.blank('')
         output = self.controller.get_vnc_console(req, fakes.FAKE_UUID,
                                                  body=body)
-        self.assertEqual(output,
-            {u'console': {u'url': u'http://fake', u'type': u'novnc'}})
+        self.assertEqual(
+            output, {'console': {'url': 'http://fake', 'type': 'novnc'}})
         mock_get_vnc_console.assert_called_once_with(
             req.environ['nova.context'], self.instance, 'novnc')
 
@@ -146,8 +147,8 @@ class ConsolesExtensionTestV21(test.NoDBTestCase):
         req = fakes.HTTPRequest.blank('')
         output = self.controller.get_spice_console(req, fakes.FAKE_UUID,
                                                    body=body)
-        self.assertEqual(output,
-            {u'console': {u'url': u'http://fake', u'type': u'spice-html5'}})
+        self.assertEqual(
+            output, {'console': {'url': 'http://fake', 'type': 'spice-html5'}})
         mock_get_spice_console.assert_called_once_with(
             req.environ['nova.context'], self.instance, 'spice-html5')
 
@@ -208,65 +209,12 @@ class ConsolesExtensionTestV21(test.NoDBTestCase):
             self.validation_error,
             body)
 
-    @mock.patch.object(compute_api.API, 'get_rdp_console',
-                       return_value={'url': 'http://fake'})
-    def test_get_rdp_console(self, mock_get_rdp_console):
+    def test_get_rdp_console_bad_request(self):
         body = {'os-getRDPConsole': {'type': 'rdp-html5'}}
         req = fakes.HTTPRequest.blank('')
-        output = self.controller.get_rdp_console(req, fakes.FAKE_UUID,
-                                                 body=body)
-        self.assertEqual(output,
-            {u'console': {u'url': u'http://fake', u'type': u'rdp-html5'}})
-        mock_get_rdp_console.assert_called_once_with(
-            req.environ['nova.context'], self.instance, 'rdp-html5')
-
-    def test_get_rdp_console_not_ready(self):
-        body = {'os-getRDPConsole': {'type': 'rdp-html5'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            webob.exc.HTTPConflict,
-            body,
-            'get_rdp_console',
-            exception.InstanceNotReady(instance_id=fakes.FAKE_UUID))
-
-    def test_get_rdp_console_no_type(self):
-        body = {'os-getRDPConsole': {}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            self.validation_error,
-            body)
-
-    def test_get_rdp_console_no_instance(self):
-        body = {'os-getRDPConsole': {'type': 'rdp-html5'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            webob.exc.HTTPNotFound,
-            body,
-            'get',
-            exception.InstanceNotFound(instance_id=fakes.FAKE_UUID))
-
-    def test_get_rdp_console_no_instance_on_console_get(self):
-        body = {'os-getRDPConsole': {'type': 'rdp-html5'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            webob.exc.HTTPNotFound,
-            body,
-            'get_rdp_console',
-            exception.InstanceNotFound(instance_id=fakes.FAKE_UUID))
-
-    def test_get_rdp_console_invalid_type(self):
-        body = {'os-getRDPConsole': {'type': 'invalid'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            self.validation_error,
-            body)
-
-    def test_get_rdp_console_type_unavailable(self):
-        body = {'os-getRDPConsole': {'type': 'unavailable'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            self.validation_error,
-            body)
+        self.assertRaises(webob.exc.HTTPBadRequest,
+                          self.controller.get_rdp_console,
+                          req, fakes.FAKE_UUID, body=body)
 
     def test_get_vnc_console_with_undefined_param(self):
         body = {'os-getVNCConsole': {'type': 'novnc', 'undefined': 'foo'}}
@@ -277,19 +225,12 @@ class ConsolesExtensionTestV21(test.NoDBTestCase):
 
     def test_get_spice_console_with_undefined_param(self):
         body = {'os-getSPICEConsole': {'type': 'spice-html5',
-                                      'undefined': 'foo'}}
+                                       'undefined': 'foo'}}
         self._check_console_failure(
             self.controller.get_spice_console,
             self.validation_error,
             body)
 
-    def test_get_rdp_console_with_undefined_param(self):
-        body = {'os-getRDPConsole': {'type': 'rdp-html5', 'undefined': 'foo'}}
-        self._check_console_failure(
-            self.controller.get_rdp_console,
-            self.validation_error,
-            body)
-
     @mock.patch.object(compute_api.API, 'get_serial_console',
                        return_value={'url': 'ws://fake'})
     def test_get_serial_console(self, mock_get_serial_console):
@@ -297,9 +238,8 @@ class ConsolesExtensionTestV21(test.NoDBTestCase):
         req = fakes.HTTPRequest.blank('')
         output = self.controller.get_serial_console(req, fakes.FAKE_UUID,
                                                     body=body)
-        self.assertEqual({u'console': {u'url': u'ws://fake',
-                                       u'type': u'serial'}},
-                         output)
+        self.assertEqual(
+            output, {'console': {'url': 'ws://fake', 'type': 'serial'}})
         mock_get_serial_console.assert_called_once_with(
             req.environ['nova.context'], self.instance, 'serial')
 
@@ -412,18 +352,10 @@ class ConsolesExtensionTestV26(test.NoDBTestCase):
         mock_handler.assert_called_once_with(self.context, self.instance,
                                              'spice-html5')
 
-    def test_create_rdp_console(self):
-        mock_handler = mock.MagicMock()
-        mock_handler.return_value = {'url': "http://fake"}
-        self.controller.handlers['rdp'] = mock_handler
-
+    def test_create_rdp_console_bad_request(self):
         body = {'remote_console': {'protocol': 'rdp', 'type': 'rdp-html5'}}
-        output = self.controller.create(self.req, fakes.FAKE_UUID, body=body)
-        self.assertEqual({'remote_console': {'protocol': 'rdp',
-                                             'type': 'rdp-html5',
-                                             'url': 'http://fake'}}, output)
-        mock_handler.assert_called_once_with(self.context, self.instance,
-                                             'rdp-html5')
+        self.assertRaises(webob.exc.HTTPBadRequest, self.controller.create,
+                          self.req, fakes.FAKE_UUID, body=body)
 
     def test_create_serial_console(self):
         mock_handler = mock.MagicMock()
@@ -539,3 +471,35 @@ class ConsolesExtensionTestV28(ConsolesExtensionTestV26):
                                              'url': 'http://fake'}}, output)
         mock_handler.assert_called_once_with(self.context, self.instance,
                                              'webmks')
+
+
+class ConsolesExtensionTestV299(ConsolesExtensionTestV26):
+    def setUp(self):
+        super(ConsolesExtensionTestV299, self).setUp()
+        self.req = fakes.HTTPRequest.blank('')
+        self.context = self.req.environ['nova.context']
+        self.req.api_version_request = api_version_request.APIVersionRequest(
+            '2.99')
+        self.controller = console_v21.RemoteConsolesController()
+
+    def test_create_spice_direct_console(self):
+        mock_handler = mock.MagicMock()
+        mock_handler.return_value = {'url': 'http://fake'}
+        self.controller.handlers['spice'] = mock_handler
+
+        body = {
+            'remote_console': {
+                'protocol': 'spice',
+                'type': 'spice-direct'
+                }
+            }
+        output = self.controller.create(self.req, fakes.FAKE_UUID, body=body)
+        self.assertEqual({
+            'remote_console': {
+                'protocol': 'spice',
+                'type': 'spice-direct',
+                'url': 'http://fake'
+                }
+            }, output)
+        mock_handler.assert_called_once_with(self.context, self.instance,
+                                             'spice-direct')
