@@ -18,28 +18,26 @@ import ddt
 from oslo_utils.fixture import uuidsentinel as uuids
 import webob
 
-from nova.api.openstack.compute import suspend_server as \
-    suspend_server_v21
+from nova.api.openstack.compute import suspend_server
 from nova import exception
 from nova.tests.unit.api.openstack.compute import admin_only_action_common
 
 
 @ddt.ddt
-class SuspendServerTestsV21(admin_only_action_common.CommonTests):
-    suspend_server = suspend_server_v21
-    controller_name = 'SuspendServerController'
-    _api_version = '2.1'
+class SuspendServerTests(admin_only_action_common.CommonTests):
 
     def setUp(self):
-        super(SuspendServerTestsV21, self).setUp()
-        self.controller = getattr(self.suspend_server, self.controller_name)()
+        super().setUp()
+        self.controller = suspend_server.SuspendServerController()
         self.compute_api = self.controller.compute_api
-        self.stub_out('nova.api.openstack.compute.suspend_server.'
-                      'SuspendServerController',
-                      lambda *a, **kw: self.controller)
 
     def test_suspend_resume(self):
-        self._test_actions(['_suspend', '_resume'])
+        self._test_actions(
+            ['_suspend', '_resume'],
+            body_map={
+                '_suspend': {'suspend': None}, '_resume': {'resume': None}
+            }
+        )
 
     @ddt.data(
         exception.OperationNotSupportedForVDPAInterface(
@@ -55,15 +53,29 @@ class SuspendServerTestsV21(admin_only_action_common.CommonTests):
         self.assertRaises(
             webob.exc.HTTPBadRequest,
             self.controller._suspend,
-            self.req, uuids.instance, body={})
+            self.req, uuids.instance, body={'suspend': None})
         self.assertTrue(mock_suspend.called)
 
     def test_suspend_resume_with_non_existed_instance(self):
-        self._test_actions_with_non_existed_instance(['_suspend', '_resume'])
+        self._test_actions_with_non_existed_instance(
+            ['_suspend', '_resume'],
+            body_map={
+                '_suspend': {'suspend': None}, '_resume': {'resume': None}
+            }
+        )
 
     def test_suspend_resume_raise_conflict_on_invalid_state(self):
-        self._test_actions_raise_conflict_on_invalid_state(['_suspend',
-                                                            '_resume'])
+        self._test_actions_raise_conflict_on_invalid_state(
+            ['_suspend', '_resume'],
+            body_map={
+                '_suspend': {'suspend': None}, '_resume': {'resume': None}
+            }
+        )
 
     def test_actions_with_locked_instance(self):
-        self._test_actions_with_locked_instance(['_suspend', '_resume'])
+        self._test_actions_with_locked_instance(
+            ['_suspend', '_resume'],
+            body_map={
+                '_suspend': {'suspend': None}, '_resume': {'resume': None}
+            }
+        )
