@@ -17,8 +17,8 @@
 Test suites for 'common' code used throughout the OpenStack HTTP API.
 """
 
-import mock
-import six
+from unittest import mock
+
 from testtools import matchers
 import webob
 import webob.exc
@@ -30,7 +30,6 @@ from nova.compute import vm_states
 from nova import exception
 from nova import test
 from nova.tests.unit.api.openstack import fakes
-from nova.tests.unit import utils
 
 
 NS = "{http://docs.openstack.org/compute/api/v1.1}"
@@ -135,7 +134,7 @@ class LimiterTest(test.NoDBTestCase):
     def test_limiter_custom_max_limit(self):
         # Test a max_limit other than 1000.
         max_limit = 2000
-        self.flags(osapi_max_limit=max_limit)
+        self.flags(max_limit=max_limit, group='api')
         items = range(max_limit)
         req = webob.Request.blank('/?offset=1&limit=3')
         self.assertEqual(
@@ -171,7 +170,7 @@ class SortParamUtilsTest(test.NoDBTestCase):
         self.assertEqual(['desc'], sort_dirs)
 
     def test_get_sort_params_override_defaults(self):
-        '''Verifies that the defaults can be overriden.'''
+        '''Verifies that the defaults can be overridden.'''
         sort_keys, sort_dirs = common.get_sort_params({}, default_key='key1',
                                                       default_dir='dir1')
         self.assertEqual(['key1'], sort_keys)
@@ -368,47 +367,12 @@ class MiscFunctionsTest(test.TestCase):
             common.raise_http_conflict_for_instance_invalid_state(exc,
                     'meow', 'fake_server_id')
         except webob.exc.HTTPConflict as e:
-            self.assertEqual(six.text_type(e),
+            self.assertEqual(str(e),
                 "Cannot 'meow' instance fake_server_id while it is in "
                 "fake_attr fake_state")
         else:
             self.fail("webob.exc.HTTPConflict was not raised")
 
-    def test_check_img_metadata_properties_quota_valid_metadata(self):
-        ctxt = utils.get_test_admin_context()
-        metadata1 = {"key": "value"}
-        actual = common.check_img_metadata_properties_quota(ctxt, metadata1)
-        self.assertIsNone(actual)
-
-        metadata2 = {"key": "v" * 260}
-        actual = common.check_img_metadata_properties_quota(ctxt, metadata2)
-        self.assertIsNone(actual)
-
-        metadata3 = {"key": ""}
-        actual = common.check_img_metadata_properties_quota(ctxt, metadata3)
-        self.assertIsNone(actual)
-
-    def test_check_img_metadata_properties_quota_inv_metadata(self):
-        ctxt = utils.get_test_admin_context()
-        metadata1 = {"a" * 260: "value"}
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                common.check_img_metadata_properties_quota, ctxt, metadata1)
-
-        metadata2 = {"": "value"}
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                common.check_img_metadata_properties_quota, ctxt, metadata2)
-
-        metadata3 = "invalid metadata"
-        self.assertRaises(webob.exc.HTTPBadRequest,
-                common.check_img_metadata_properties_quota, ctxt, metadata3)
-
-        metadata4 = None
-        self.assertIsNone(common.check_img_metadata_properties_quota(ctxt,
-                                                        metadata4))
-        metadata5 = {}
-        self.assertIsNone(common.check_img_metadata_properties_quota(ctxt,
-                                                        metadata5))
-
     def test_status_from_state(self):
         for vm_state in (vm_states.ACTIVE, vm_states.STOPPED):
             for task_state in (task_states.RESIZE_PREP,
@@ -530,7 +494,7 @@ class TestCollectionLinks(test.NoDBTestCase):
         req = mock.MagicMock()
         params = mock.PropertyMock(return_value=dict())
         type(req).params = params
-        self.flags(osapi_max_limit=1)
+        self.flags(max_limit=1, group='api')
 
         builder = common.ViewBuilder()
         results = builder._get_collection_links(req, items,
@@ -550,7 +514,7 @@ class TestCollectionLinks(test.NoDBTestCase):
         # Given limit is greater than default max, only return default max
         params = mock.PropertyMock(return_value=dict(limit=2))
         type(req).params = params
-        self.flags(osapi_max_limit=1)
+        self.flags(max_limit=1, group='api')
 
         builder = common.ViewBuilder()
         results = builder._get_collection_links(req, items,
@@ -614,7 +578,7 @@ class UrlJoinTest(test.NoDBTestCase):
 
 
 class ViewBuilderLinkTest(test.NoDBTestCase):
-    project_id = "fake"
+    project_id = fakes.FAKE_PROJECT_ID
     api_version = "2.1"
 
     def setUp(self):
@@ -630,6 +594,11 @@ class ViewBuilderLinkTest(test.NoDBTestCase):
         proj_id = self.vb._get_project_id(self.request)
         self.assertEqual(self.project_id, proj_id)
 
+    def test_get_project_id_with_none_project_id(self):
+        self.request.environ["nova.context"].project_id = None
+        proj_id = self.vb._get_project_id(self.request)
+        self.assertEqual('', proj_id)
+
     def test_get_next_link(self):
         identifier = "identifier"
         collection = "collection"
