@@ -10,28 +10,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-import six
+from unittest import mock
+
+from oslo_serialization import jsonutils
 import testscenarios
 import webob
 
 from nova.api.openstack import api_version_request as api_version
-from nova.api.openstack import extensions
-from nova.api.openstack import versioned_method
 from nova.api.openstack import wsgi
 from nova import exception
-from nova import i18n
 from nova import test
 from nova.tests.unit.api.openstack import fakes
 from nova.tests.unit import matchers
 from nova.tests.unit import utils
-from oslo_serialization import jsonutils
 
 
 class MicroversionedTest(testscenarios.WithScenarios, test.NoDBTestCase):
 
     scenarios = [
-        ('legacy-microverison', {
+        ('legacy-microversion', {
             'header_name': 'X-OpenStack-Nova-API-Version',
         }),
         ('modern-microversion', {
@@ -48,6 +45,12 @@ class MicroversionedTest(testscenarios.WithScenarios, test.NoDBTestCase):
 
 class RequestTest(MicroversionedTest):
 
+    def setUp(self):
+        super(RequestTest, self).setUp()
+        self.stub_out('nova.i18n.get_available_languages',
+                      lambda *args, **kwargs:
+                      ['en-GB', 'en-AU', 'de', 'zh-CN', 'en-US', 'ja-JP'])
+
     def test_content_type_missing(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
         request.body = b"<body />"
@@ -72,103 +75,61 @@ class RequestTest(MicroversionedTest):
         result = request.best_match_content_type()
         self.assertEqual(result, "application/json")
 
-    def test_cache_and_retrieve_instances(self):
-        request = wsgi.Request.blank('/foo')
-        instances = []
-        for x in range(3):
-            instances.append({'uuid': 'uuid%s' % x})
-        # Store 2
-        request.cache_db_instances(instances[:2])
-        # Store 1
-        request.cache_db_instance(instances[2])
-        self.assertEqual(request.get_db_instance('uuid0'),
-                instances[0])
-        self.assertEqual(request.get_db_instance('uuid1'),
-                instances[1])
-        self.assertEqual(request.get_db_instance('uuid2'),
-                instances[2])
-        self.assertIsNone(request.get_db_instance('uuid3'))
-        self.assertEqual(request.get_db_instances(),
-                {'uuid0': instances[0],
-                 'uuid1': instances[1],
-                 'uuid2': instances[2]})
-
-    def test_cache_and_retrieve_compute_nodes(self):
-        request = wsgi.Request.blank('/foo')
-        compute_nodes = []
-        for x in range(3):
-            compute_nodes.append({'id': 'id%s' % x})
-        # Store 2
-        request.cache_db_compute_nodes(compute_nodes[:2])
-        # Store 1
-        request.cache_db_compute_node(compute_nodes[2])
-        self.assertEqual(request.get_db_compute_node('id0'),
-                compute_nodes[0])
-        self.assertEqual(request.get_db_compute_node('id1'),
-                compute_nodes[1])
-        self.assertEqual(request.get_db_compute_node('id2'),
-                compute_nodes[2])
-        self.assertIsNone(request.get_db_compute_node('id3'))
-        self.assertEqual(request.get_db_compute_nodes(),
-                {'id0': compute_nodes[0],
-                 'id1': compute_nodes[1],
-                 'id2': compute_nodes[2]})
+    def test_content_type_accept_with_quality_values(self):
+        request = wsgi.Request.blank('/tests/123')
+        request.headers["Accept"] = (
+            "application/json;q=0.4,"
+            "application/vnd.openstack.compute+json;q=0.6")
+        result = request.best_match_content_type()
+        self.assertEqual("application/vnd.openstack.compute+json", result)
 
     def test_from_request(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
-        accepted = 'bogus;q=1.1, en-gb;q=0.7,en-us,en;q=.5,*;q=.7'
+        accepted = 'bogus;q=1, en-gb;q=0.7,en-us,en;q=0.5,*;q=0.7'
         request.headers = {'Accept-Language': accepted}
-        self.assertEqual(request.best_match_language(), 'en_US')
+        self.assertEqual(request.best_match_language(), 'en-US')
 
     def test_asterisk(self):
-        # asterisk should match first available if there
-        # are not any other available matches
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
+        # In the section 3.4 of RFC4647, it says as follows:
+        # If the language range "*"(asterisk) is the only one
+        # in the language priority list or if no other language range
+        # follows, the default value is computed and returned.
+        #
+        # In this case, the default value 'None' is returned.
         request = wsgi.Request.blank('/')
-        accepted = '*,es;q=.5'
+        accepted = '*;q=0.5'
         request.headers = {'Accept-Language': accepted}
-        self.assertEqual(request.best_match_language(), 'en_GB')
-
-    def test_prefix(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
+        self.assertIsNone(request.best_match_language())
 
+    def test_asterisk_followed_by_other_language(self):
         request = wsgi.Request.blank('/')
-        accepted = 'zh'
+        accepted = '*,ja-jp;q=0.5'
         request.headers = {'Accept-Language': accepted}
-        self.assertEqual(request.best_match_language(), 'zh_CN')
+        self.assertEqual('ja-JP', request.best_match_language())
+
+    def test_truncate(self):
+        request = wsgi.Request.blank('/')
+        accepted = 'de-CH'
+        request.headers = {'Accept-Language': accepted}
+        self.assertEqual('de', request.best_match_language())
 
     def test_secondary(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
-        accepted = 'nn,en-gb;q=.5'
+        accepted = 'nn,en-gb;q=0.5'
         request.headers = {'Accept-Language': accepted}
-        self.assertEqual(request.best_match_language(), 'en_GB')
+        self.assertEqual('en-GB', request.best_match_language())
 
     def test_none_found(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = 'nb-no'
         request.headers = {'Accept-Language': accepted}
-        self.assertIs(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
 
     def test_no_lang_header(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = ''
         request.headers = {'Accept-Language': accepted}
-        self.assertIs(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
 
     def test_api_version_request_header_none(self):
         request = wsgi.Request.blank('/')
@@ -290,7 +251,7 @@ class ResourceTest(MicroversionedTest):
     def get_req_id_header_name(self, request):
         header_name = 'x-openstack-request-id'
         if utils.get_api_version(request) < 3:
-                header_name = 'x-compute-request-id'
+            header_name = 'x-compute-request-id'
 
         return header_name
 
@@ -303,7 +264,7 @@ class ResourceTest(MicroversionedTest):
                     raise webob.exc.HTTPInternalServerError()
                 return 'success'
 
-        app = fakes.TestRouterV21(Controller())
+        app = fakes.TestRouter(Controller())
         req = webob.Request.blank('/tests')
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
@@ -321,7 +282,7 @@ class ResourceTest(MicroversionedTest):
                     raise webob.exc.HTTPInternalServerError()
                 return 'success'
 
-        app = fakes.TestRouterV21(Controller())
+        app = fakes.TestRouter(Controller())
         req = webob.Request.blank('/tests')
         req.headers = self._make_microversion_header(version)
         response = req.get_response(app)
@@ -335,7 +296,7 @@ class ResourceTest(MicroversionedTest):
             def index(self, req):
                 return 'success'
 
-        app = fakes.TestRouterV21(Controller())
+        app = fakes.TestRouter(Controller())
         req = webob.Request.blank('/tests')
         req.headers = self._make_microversion_header(invalid_version)
         response = req.get_response(app)
@@ -363,7 +324,7 @@ class ResourceTest(MicroversionedTest):
 
     def test_resource_call_with_method_post(self):
         class Controller(object):
-            @extensions.expected_errors(400)
+            @wsgi.expected_errors(400)
             def create(self, req, body):
                 if expected_body != body:
                     msg = "The request body invalid"
@@ -475,7 +436,7 @@ class ResourceTest(MicroversionedTest):
 
         controller = Controller()
         resource = wsgi.Resource(controller)
-        method, extensions = resource.get_method(None, 'index', None, '')
+        method = resource.get_method(None, 'index', None, '')
         actual = resource.dispatch(method, None, {'pants': 'off'})
         expected = 'off'
         self.assertEqual(actual, expected)
@@ -498,9 +459,9 @@ class ResourceTest(MicroversionedTest):
 
         controller = Controller()
         resource = wsgi.Resource(controller)
-        method, extensions = resource.get_method(None, 'action',
-                                                 'application/json',
-                                                 '{"fooAction": true}')
+        method = resource.get_method(None, 'action',
+                                     'application/json',
+                                     '{"fooAction": true}')
         self.assertEqual(controller._action_foo, method)
 
     def test_get_method_action_bad_body(self):
@@ -533,9 +494,9 @@ class ResourceTest(MicroversionedTest):
 
         controller = Controller()
         resource = wsgi.Resource(controller)
-        method, extensions = resource.get_method(None, 'action',
-                                                 'application/xml',
-                                                 '<fooAction>true</fooAction')
+        method = resource.get_method(None, 'action',
+                                     'application/xml',
+                                     '<fooAction>true</fooAction')
         self.assertEqual(controller.action, method)
 
     def test_get_action_args(self):
@@ -605,6 +566,16 @@ class ResourceTest(MicroversionedTest):
         self.assertEqual('application/json', content_type)
         self.assertEqual(b'', body)
 
+    def test_get_body_content_body_none(self):
+        resource = wsgi.Resource(None)
+        request = wsgi.Request.blank('/', method='PUT')
+        body = None
+
+        contents = resource._get_request_content(body, request)
+
+        self.assertIn('body', contents)
+        self.assertIsNone(contents['body'])
+
     def test_get_body(self):
         class Controller(object):
             def index(self, req, pants=None):
@@ -697,50 +668,17 @@ class ResourceTest(MicroversionedTest):
                 'barAction': extended._action_bar,
                 }, resource.wsgi_actions)
 
-    def test_register_extensions(self):
+    def test_get_method(self):
         class Controller(object):
             def index(self, req, pants=None):
                 return pants
 
-        class ControllerExtended(wsgi.Controller):
-            @wsgi.extends
-            def index(self, req, resp_obj, pants=None):
-                return None
-
-            @wsgi.extends(action='fooAction')
-            def _action_foo(self, req, resp, id, body):
-                return None
-
         controller = Controller()
         resource = wsgi.Resource(controller)
-        self.assertEqual({}, resource.wsgi_extensions)
-        self.assertEqual({}, resource.wsgi_action_extensions)
-
-        extended = ControllerExtended()
-        resource.register_extensions(extended)
-        self.assertEqual({'index': [extended.index]}, resource.wsgi_extensions)
-        self.assertEqual({'fooAction': [extended._action_foo]},
-                         resource.wsgi_action_extensions)
-
-    def test_get_method_extensions(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        class ControllerExtended(wsgi.Controller):
-            @wsgi.extends
-            def index(self, req, resp_obj, pants=None):
-                return None
-
-        controller = Controller()
-        extended = ControllerExtended()
-        resource = wsgi.Resource(controller)
-        resource.register_extensions(extended)
-        method, extensions = resource.get_method(None, 'index', None, '')
+        method = resource.get_method(None, 'index', None, '')
         self.assertEqual(method, controller.index)
-        self.assertEqual(extensions, [extended.index])
 
-    def test_get_method_action_extensions(self):
+    def test_get_method_action(self):
         class Controller(wsgi.Controller):
             def index(self, req, pants=None):
                 return pants
@@ -749,22 +687,14 @@ class ResourceTest(MicroversionedTest):
             def _action_foo(self, req, id, body):
                 return body
 
-        class ControllerExtended(wsgi.Controller):
-            @wsgi.extends(action='fooAction')
-            def _action_foo(self, req, resp_obj, id, body):
-                return None
-
         controller = Controller()
-        extended = ControllerExtended()
         resource = wsgi.Resource(controller)
-        resource.register_extensions(extended)
-        method, extensions = resource.get_method(None, 'action',
-                                                 'application/json',
-                                                 '{"fooAction": true}')
+        method = resource.get_method(None, 'action',
+                                     'application/json',
+                                     '{"fooAction": true}')
         self.assertEqual(method, controller._action_foo)
-        self.assertEqual(extensions, [extended._action_foo])
 
-    def test_get_method_action_whitelist_extensions(self):
+    def test_get_method_action_whitelist(self):
         class Controller(wsgi.Controller):
             def index(self, req, pants=None):
                 return pants
@@ -783,61 +713,13 @@ class ResourceTest(MicroversionedTest):
         resource = wsgi.Resource(controller)
         resource.register_actions(extended)
 
-        method, extensions = resource.get_method(None, 'create',
-                                                 'application/json',
-                                                 '{"create": true}')
+        method = resource.get_method(None, 'create',
+                                     'application/json',
+                                     '{"create": true}')
         self.assertEqual(method, extended._create)
-        self.assertEqual(extensions, [])
 
-        method, extensions = resource.get_method(None, 'delete', None, None)
+        method = resource.get_method(None, 'delete', None, None)
         self.assertEqual(method, extended._delete)
-        self.assertEqual(extensions, [])
-
-    def test_process_extensions_regular(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req, resp_obj):
-            called.append(1)
-            return None
-
-        def extension2(req, resp_obj):
-            called.append(2)
-            return None
-
-        response = resource.process_extensions([extension2, extension1],
-                                                    None, None, {})
-        self.assertEqual(called, [2, 1])
-        self.assertIsNone(response)
-
-    def test_process_extensions_regular_response(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req, resp_obj):
-            called.append(1)
-            return None
-
-        def extension2(req, resp_obj):
-            called.append(2)
-            return 'foo'
-
-        response = resource.process_extensions([extension2, extension1],
-                                                    None, None, {})
-        self.assertEqual(called, [2])
-        self.assertEqual(response, 'foo')
 
     def test_resource_exception_handler_type_error(self):
         # A TypeError should be translated to a Fault/HTTP 400.
@@ -864,12 +746,12 @@ class ResourceTest(MicroversionedTest):
         req = webob.Request.blank('/tests')
         app = fakes.TestRouter(Controller())
         response = req.get_response(app)
-        for val in six.itervalues(response.headers):
+        for val in response.headers.values():
             # All headers must be utf8
             self.assertThat(val, matchers.EncodedByUTF8())
-        self.assertEqual(b'1', response.headers['x-header1'])
-        self.assertEqual(b'header2', response.headers['x-header2'])
-        self.assertEqual(b'header3', response.headers['x-header3'])
+        self.assertEqual('1', response.headers['x-header1'])
+        self.assertEqual('header2', response.headers['x-header2'])
+        self.assertEqual('header3', response.headers['x-header3'])
 
     def test_resource_valid_utf8_body(self):
         class Controller(object):
@@ -971,74 +853,122 @@ class ValidBodyTest(test.NoDBTestCase):
         self.assertFalse(self.controller.is_valid_body(body, 'foo'))
 
 
-class TestController(test.NoDBTestCase):
-    def test_check_for_versions_intersection_negative(self):
-        func_list = \
-            [versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.1'),
-                                              api_version.APIVersionRequest(
-                                                  '2.4'),
-                                              None),
-             versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.11'),
-                                              api_version.APIVersionRequest(
-                                                  '3.1'),
-                                              None),
-             versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.8'),
-                                              api_version.APIVersionRequest(
-                                                  '2.9'),
-                                              None),
-             ]
+class APIVersionTestCase(test.NoDBTestCase):
 
-        result = wsgi.Controller.check_for_versions_intersection(func_list=
-                                                                 func_list)
-        self.assertFalse(result)
+    def test_api_version(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.api_version('2.10', '2.19')
+            def fake_func(self, req):
+                return {'resources': []}
 
-        func_list = \
-            [versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.12'),
-                                              api_version.APIVersionRequest(
-                                                  '2.14'),
-                                              None),
-             versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '3.0'),
-                                              api_version.APIVersionRequest(
-                                                  '3.4'),
-                                              None)
-             ]
+        controller = FakeController()
 
-        result = wsgi.Controller.check_for_versions_intersection(func_list=
-                                                                 func_list)
-        self.assertFalse(result)
+        req = fakes.HTTPRequest.blank('', version='2.10')
+        self.assertEqual({'resources': []}, controller.fake_func(req))
 
-    def test_check_for_versions_intersection_positive(self):
-        func_list = \
-            [versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.1'),
-                                              api_version.APIVersionRequest(
-                                                  '2.4'),
-                                              None),
-             versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.3'),
-                                              api_version.APIVersionRequest(
-                                                  '3.0'),
-                                              None),
-             versioned_method.VersionedMethod('foo',
-                                              api_version.APIVersionRequest(
-                                                  '2.8'),
-                                              api_version.APIVersionRequest(
-                                                  '2.9'),
-                                              None),
-             ]
+        req = fakes.HTTPRequest.blank('', version='2.19')
+        self.assertEqual({'resources': []}, controller.fake_func(req))
 
-        result = wsgi.Controller.check_for_versions_intersection(func_list=
-                                                                 func_list)
-        self.assertTrue(result)
+        req = fakes.HTTPRequest.blank('', version='2.9')
+        self.assertRaises(
+            exception.VersionNotFoundForAPIMethod, controller.fake_func, req
+        )
+
+        req = fakes.HTTPRequest.blank('', version='2.20')
+        self.assertRaises(
+            exception.VersionNotFoundForAPIMethod, controller.fake_func, req
+        )
+
+    def test_api_version_legacy(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.api_version('2.0', '2.10')
+            def fake_func(self, req):
+                return {'resources': []}
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        req.set_legacy_v2()
+        self.assertEqual({'resources': []}, controller.fake_func(req))
+
+
+class ExpectedErrorTestCase(test.NoDBTestCase):
+
+    def test_expected_error(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors(404)
+            def fake_func(self, req):
+                raise webob.exc.HTTPNotFound()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        self.assertRaises(webob.exc.HTTPNotFound, controller.fake_func, req)
+
+    def test_expected_error_from_list(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors((404, 403))
+            def fake_func(self, req):
+                raise webob.exc.HTTPNotFound()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        self.assertRaises(webob.exc.HTTPNotFound, controller.fake_func, req)
+
+    def test_expected_error_with_microversion(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors(404, '2.1', '2.5')
+            @wsgi.expected_errors((400, 404), '2.6')
+            def fake_func(self, req):
+                raise webob.exc.HTTPBadRequest()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('', version='2.7')
+        self.assertRaises(webob.exc.HTTPBadRequest, controller.fake_func, req)
+
+    def test_unexpected_error(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors(404)
+            def fake_func(self, req):
+                raise webob.exc.HTTPConflict()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        self.assertRaises(
+            webob.exc.HTTPInternalServerError, controller.fake_func, req
+        )
+
+    def test_unexpected_error_from_list(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors((404, 413))
+            def fake_func(self, req):
+                raise webob.exc.HTTPConflict()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        self.assertRaises(
+            webob.exc.HTTPInternalServerError, controller.fake_func, req
+        )
+
+    def test_unexpected_error_with_microversion(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors(404, '2.1', '2.5')
+            @wsgi.expected_errors((400, 404), '2.6')
+            def fake_func(self, req):
+                raise webob.exc.HTTPBadRequest()
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('', version='2.5')
+        self.assertRaises(
+            webob.exc.HTTPInternalServerError, controller.fake_func, req
+        )
+
+    def test_unexpected_policy_not_authorized_error(self):
+        class FakeController(wsgi.Controller):
+            @wsgi.expected_errors(404)
+            def fake_func(self, req):
+                raise exception.PolicyNotAuthorized(action="foo")
+
+        controller = FakeController()
+        req = fakes.HTTPRequest.blank('')
+        self.assertRaises(
+            exception.PolicyNotAuthorized, controller.fake_func, req
+        )
