@@ -355,11 +355,6 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
                 instance=self.fake_instance_obj, console_type='type',
                 version='6.0')
 
-    def test_get_rdp_console(self):
-        self._test_compute_api('get_rdp_console', 'call',
-                instance=self.fake_instance_obj, console_type='type',
-                version='6.0')
-
     def test_get_serial_console(self):
         self._test_compute_api('get_serial_console', 'call',
                 instance=self.fake_instance_obj, console_type='serial',
@@ -836,7 +831,8 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             orig_sys_metadata=None, recreate=True, on_shared_storage=True,
             preserve_ephemeral=True, migration=None, node=None,
             limits=None, request_spec=None, accel_uuids=[],
-            reimage_boot_volume=False, version='6.1')
+            reimage_boot_volume=False, target_state=None,
+            version='6.2')
 
     def test_rebuild_instance_old_rpcapi(self):
         # With rpcapi < 5.12, accel_uuids must be dropped in the client call.
@@ -868,9 +864,11 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             ctxt, instance=self.fake_instance_obj,
             accel_uuids=['938af7f9-f136-4e5a-bdbe-3b6feab54311'],
             node=None, host=None, reimage_boot_volume=False,
-            **rebuild_args)
+            target_state=None, **rebuild_args)
 
-        mock_client.can_send_version.assert_has_calls([mock.call('6.0'),
+        mock_client.can_send_version.assert_has_calls([mock.call('6.2'),
+                                                       mock.call('6.1'),
+                                                       mock.call('6.0'),
                                                        mock.call('5.12')])
         mock_client.prepare.assert_called_with(
                 server=self.fake_instance_obj.host, version='5.0')
@@ -890,7 +888,7 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
         compute_api.router.client.return_value = mock_client
         # Force can_send_version to [False, True, True], so that 6.0
         # version is used.
-        mock_client.can_send_version.side_effect = [False, True, True]
+        mock_client.can_send_version.side_effect = [False, False, True, True]
         mock_cctx = mock.MagicMock()
         mock_client.prepare.return_value = mock_cctx
         rebuild_args = {
@@ -908,12 +906,47 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             'limits': None,
             'accel_uuids': [],
             'reimage_boot_volume': True,
+            'target_state': None,
         }
         self.assertRaises(
             exception.NovaException, compute_api.rebuild_instance,
             ctxt, instance=self.fake_instance_obj,
             node=None, host=None, **rebuild_args)
-        mock_client.can_send_version.assert_has_calls([mock.call('6.1')])
+        mock_client.can_send_version.assert_has_calls([mock.call('6.2')])
+
+    def test_rebuild_instance_evacuate_old_rpcapi(self):
+        # With rpcapi < 6.2, if evacuate we should raise error.
+        ctxt = context.RequestContext('fake_user', 'fake_project')
+        compute_api = compute_rpcapi.ComputeAPI()
+        compute_api.router.client = mock.Mock()
+        mock_client = mock.MagicMock()
+        compute_api.router.client.return_value = mock_client
+        # Force can_send_version to return False.
+        mock_client.can_send_version.return_value = False
+        mock_cctx = mock.MagicMock()
+        mock_client.prepare.return_value = mock_cctx
+        rebuild_args = {
+            'new_pass': 'admin_password',
+            'injected_files': 'files_to_inject',
+            'image_ref': uuids.image_ref,
+            'orig_image_ref': uuids.orig_image_ref,
+            'orig_sys_metadata': 'orig_sys_meta',
+            'bdms': {},
+            'recreate': False,
+            'on_shared_storage': False,
+            'preserve_ephemeral': False,
+            'request_spec': None,
+            'migration': None,
+            'limits': None,
+            'accel_uuids': [],
+            'reimage_boot_volume': True,
+            'target_state': 'stopped',
+        }
+        self.assertRaises(
+            exception.UnsupportedRPCVersion,
+            compute_api.rebuild_instance,
+            ctxt, instance=self.fake_instance_obj,
+            node=None, host=None, **rebuild_args)
 
     def test_reserve_block_device_name(self):
         self.flags(long_rpc_timeout=1234)
@@ -932,7 +965,7 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
     def test_remove_volume_connection(self):
         self._test_compute_api('remove_volume_connection', 'call',
                 instance=self.fake_instance_obj, volume_id='id', host='host',
-                version='6.0')
+                delete_attachment=True, version='6.3')
 
     def test_rescue_instance(self):
         self._test_compute_api('rescue_instance', 'cast',
@@ -1294,3 +1327,30 @@ class ComputeRpcAPITestCase(test.NoDBTestCase):
             'access the database. You should run this '
             'service without the [api_database]/connection '
             'config option.')
+
+    def get_fake_share_mapping(self):
+        share_mapping = objects.ShareMapping(self.context)
+        share_mapping.uuid = uuids.share_mapping
+        share_mapping.instance_uuid = uuids.instance
+        share_mapping.share_id = uuids.share
+        share_mapping.status = 'inactive'
+        share_mapping.tag = 'fake_tag'
+        share_mapping.export_location = '192.168.122.152:/manila/share'
+        share_mapping.share_proto = 'NFS'
+        return share_mapping
+
+    def test_allow_share(self):
+        self._test_compute_api(
+            'allow_share',
+            'cast',
+            instance=self.fake_instance_obj,
+            share_mapping=self.get_fake_share_mapping(),
+            version='6.4')
+
+    def test_deny_share(self):
+        self._test_compute_api(
+            'deny_share',
+            'cast',
+            instance=self.fake_instance_obj,
+            share_mapping=self.get_fake_share_mapping(),
+            version='6.4')
