@@ -12,7 +12,6 @@
 
 from unittest import mock
 
-import eventlet
 from oslo_utils import fixture as utils_fixture
 from oslo_utils.fixture import uuidsentinel as uuids
 from oslo_utils import timeutils
@@ -209,6 +208,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
         instance = self._shelve_offload(clean_shutdown=False)
         mock_power_off.assert_called_once_with(instance, 0, 0)
 
+    @mock.patch.object(neutron_api.API, 'unbind_ports')
     @mock.patch.object(compute_utils, 'EventReporter')
     @mock.patch.object(objects.BlockDeviceMappingList, 'get_by_instance_uuid')
     @mock.patch.object(nova.compute.manager.ComputeManager,
@@ -225,7 +225,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
     def _shelve_offload(self, mock_notify, mock_notify_instance_usage,
                         mock_get_power_state, mock_update_resource_tracker,
                         mock_delete_alloc, mock_terminate, mock_get_bdms,
-                        mock_event, clean_shutdown=True):
+                        mock_event, mock_unbind_ports, clean_shutdown=True):
         host = 'fake-mini'
         instance = self._create_fake_instance_obj(params={'host': host})
         instance.task_state = task_states.SHELVING
@@ -278,10 +278,13 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
                                            instance.uuid,
                                            graceful_exit=False)
 
+        mock_unbind_ports.assert_called_once_with(
+            self.context, mock.ANY, detach=False)
+
         return instance
 
     @mock.patch('nova.compute.utils.'
-                'update_pci_request_spec_with_allocated_interface_name',
+                'update_pci_request_with_placement_allocations',
                 new=mock.NonCallableMock())
     @mock.patch('nova.objects.BlockDeviceMappingList.get_by_instance_uuid')
     @mock.patch('nova.compute.utils.notify_about_instance_action')
@@ -444,9 +447,9 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
             mock_bdms, mock_nil):
         instance = self._create_fake_instance_obj()
 
-        mock_get_arqs.side_effect = eventlet.timeout.Timeout()
+        mock_get_arqs.side_effect = exception.InstanceEventTimeout()
 
-        self.assertRaises(eventlet.timeout.Timeout,
+        self.assertRaises(exception.InstanceEventTimeout,
                           self.test_unshelve,
                           accel_uuids=[uuids.fake],
                           instance=instance)
@@ -592,14 +595,6 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
                 # This is before we've failed.
                 self.assertEqual(task_states.SPAWNING, instance.task_state)
                 tracking['last_state'] = instance.task_state
-            elif tracking['last_state'] == task_states.SPAWNING:
-                # This is after we've failed.
-                self.assertIsNone(instance.host)
-                self.assertIsNone(instance.node)
-                self.assertIsNone(instance.task_state)
-                tracking['last_state'] = instance.task_state
-            else:
-                self.fail('Unexpected save!')
 
         with mock.patch.object(instance, 'save') as mock_save:
             mock_save.side_effect = check_save
@@ -610,6 +605,10 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
                               request_spec=objects.RequestSpec(),
                               accel_uuids=[])
 
+        self.assertIsNone(instance.host)
+        self.assertIsNone(instance.node)
+        self.assertIsNone(instance.task_state)
+
         mock_notify_instance_action.assert_called_once_with(
             self.context, instance, 'fake-mini', action='unshelve',
             phase='start', bdms=mock_bdms)
@@ -631,7 +630,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
 
     @mock.patch('nova.network.neutron.API.setup_instance_network_on_host')
     @mock.patch('nova.compute.utils.'
-                'update_pci_request_spec_with_allocated_interface_name')
+                'update_pci_request_with_placement_allocations')
     def test_unshelve_with_resource_request(
             self, mock_update_pci, mock_setup_network):
         requested_res = [objects.RequestGroup(
@@ -642,7 +641,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
 
         self.compute.unshelve_instance(
             self.context, instance, image=None,
-            filter_properties={}, node='fake-node', request_spec=request_spec,
+            filter_properties={}, node='fakenode1', request_spec=request_spec,
             accel_uuids=[])
 
         mock_update_pci.assert_called_once_with(
@@ -655,7 +654,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
     @mock.patch('nova.network.neutron.API.setup_instance_network_on_host',
                 new=mock.NonCallableMock())
     @mock.patch('nova.compute.utils.'
-                'update_pci_request_spec_with_allocated_interface_name')
+                'update_pci_request_with_placement_allocations')
     def test_unshelve_with_resource_request_update_raises(
             self, mock_update_pci):
         requested_res = [objects.RequestGroup(
@@ -696,7 +695,7 @@ class ShelveComputeManagerTestCase(test_compute.BaseTestCase):
             self.assertRaises(test.TestingException,
                     self.compute.unshelve_instance, self.context, instance,
                     image=shelved_image, filter_properties={},
-                    node='fake-node', request_spec=fake_spec, accel_uuids=[])
+                    node='fakenode1', request_spec=fake_spec, accel_uuids=[])
         self.assertEqual(instance.image_ref, initial_image_ref)
 
     @mock.patch.object(objects.InstanceList, 'get_by_filters')
