@@ -16,8 +16,10 @@
 
 """Tests For miscellaneous util methods used with compute."""
 
+import collections
 import copy
 import datetime
+import socket
 import string
 from unittest import mock
 
@@ -36,6 +38,7 @@ from nova import context
 from nova import exception
 from nova.image import glance
 from nova.network import model
+from nova.notifications.objects import base as notifications_objects_base
 from nova import objects
 from nova.objects import base
 from nova.objects import block_device as block_device_obj
@@ -472,6 +475,31 @@ class UsageInfoTestCase(test.TestCase):
             glance.generate_glance_url(self.context), uuids.fake_image_ref)
         self.assertEqual(payload['image_ref_url'], image_ref_url)
 
+    def test_notify_about_instance_action_best_effort(self):
+        instance = create_instance(self.context)
+        bdms = block_device_obj.block_device_make_list(
+            self.context,
+            [fake_block_device.FakeDbBlockDeviceDict(
+                {'source_type': 'volume',
+                 'device_name': '/dev/vda',
+                 'instance_uuid': 'f8000000-0000-0000-0000-000000000000',
+                 'destination_type': 'volume',
+                 'boot_index': 0,
+                 'volume_id': 'de8836ac-d75e-11e2-8271-5254009297d6'})])
+        with mock.patch.object(
+            notifications_objects_base.NotificationBase, 'emit',
+            side_effect=Exception()
+        ) as mock_emit:
+            compute_utils.notify_about_instance_action(
+                self.context,
+                instance,
+                host='fake-compute',
+                action='delete',
+                phase='start',
+                bdms=bdms,
+                best_effort=True)
+            mock_emit.assert_called_once()
+
     def test_notify_about_instance_action(self):
         instance = create_instance(self.context)
         bdms = block_device_obj.block_device_make_list(
@@ -873,6 +901,24 @@ class UsageInfoTestCase(test.TestCase):
         self.assertEqual(200, payload['write_bytes'])
         self.assertEqual(200, payload['writes'])
 
+    def test_notify_about_instance_usage_best_effort(self):
+        instance = create_instance(self.context)
+        # Set some system metadata
+        sys_metadata = {'image_md_key1': 'val1',
+                        'image_md_key2': 'val2',
+                        'other_data': 'meow'}
+        instance.system_metadata.update(sys_metadata)
+        instance.save()
+        extra_usage_info = {'image_name': 'fake_name'}
+        notifier = rpc.get_notifier('compute')
+        with mock.patch.object(
+            notifier, 'info', side_effect=Exception()
+        ) as mock_info:
+            compute_utils.notify_about_instance_usage(
+                notifier, self.context, instance, 'create.start',
+                extra_usage_info=extra_usage_info, best_effort=True)
+            mock_info.assert_called_once()
+
     def test_notify_about_instance_usage(self):
         instance = create_instance(self.context)
         # Set some system metadata
@@ -1111,17 +1157,31 @@ class ComputeUtilsTestCase(test.NoDBTestCase):
         self.assertRaises(test.TestingException,
                           self._test_event_reporter_graceful_exit, error)
 
-    @mock.patch('netifaces.interfaces')
-    def test_get_machine_ips_value_error(self, mock_interfaces):
-        # Tests that the utility method does not explode if netifaces raises
-        # a ValueError.
-        iface = mock.sentinel
-        mock_interfaces.return_value = [iface]
-        with mock.patch('netifaces.ifaddresses',
-                        side_effect=ValueError) as mock_ifaddresses:
-            addresses = compute_utils.get_machine_ips()
-            self.assertEqual([], addresses)
-        mock_ifaddresses.assert_called_once_with(iface)
+    @mock.patch('psutil.net_if_addrs')
+    def test_get_machine_ips(self, mock_addrs):
+        fakeaddr = collections.namedtuple('fakeaddr', ['family', 'address'])
+        mock_addrs.return_value = {
+            'eth0': [
+                fakeaddr(family=socket.AF_INET, address='192.0.2.2'),
+                fakeaddr(family=socket.AF_INET6, address='2001:db8::10'),
+                fakeaddr(family=socket.AF_PACKET, address='10:00:00:00:00:10')
+            ],
+            'eth1': [
+                fakeaddr(family=socket.AF_INET, address='192.0.2.130'),
+                fakeaddr(family=socket.AF_INET6,
+                         address='2001:db8::f010%eth1'),
+                fakeaddr(family=socket.AF_PACKET, address='10:00:00:00:00:11')
+            ]
+        }
+        self.assertEqual(
+            [
+                '192.0.2.2',
+                '2001:db8::10',
+                '192.0.2.130',
+                '2001:db8::f010'
+            ],
+            compute_utils.get_machine_ips()
+        )
 
     @mock.patch('nova.compute.utils.notify_about_instance_action')
     @mock.patch('nova.compute.utils.notify_about_instance_usage')
@@ -1558,47 +1618,86 @@ class PciRequestUpdateTestCase(test.NoDBTestCase):
     def test_no_pci_request(self):
         provider_mapping = {}
 
-        compute_utils.update_pci_request_spec_with_allocated_interface_name(
+        compute_utils.update_pci_request_with_placement_allocations(
             self.context, mock.sentinel.report_client, [], provider_mapping)
 
-    def test_pci_request_from_flavor(self):
-        pci_requests = [objects.InstancePCIRequest(requester_id=None)]
+    def test_pci_request_from_flavor_no_mapping(self):
+        req = objects.InstancePCIRequest(
+            requester_id=None,
+            request_id=uuids.req1,
+            alias_name="a-dev",
+            spec=[{}],
+        )
+        pci_requests = [req]
+
         provider_mapping = {}
 
-        compute_utils.update_pci_request_spec_with_allocated_interface_name(
+        compute_utils.update_pci_request_with_placement_allocations(
             self.context, mock.sentinel.report_client, pci_requests,
             provider_mapping)
 
+        self.assertNotIn('rp_uuids', req.spec[0])
+
+    def test_pci_request_from_flavor_with_mapping(self):
+        req = objects.InstancePCIRequest(
+            requester_id=None,
+            request_id=uuids.req1,
+            alias_name="a-dev",
+            spec=[{}],
+        )
+        pci_requests = [req]
+
+        provider_mapping = {
+            f"{uuids.req1}-0": [uuids.rp1],
+            f"{uuids.req1}-1": [uuids.rp2],
+        }
+
+        compute_utils.update_pci_request_with_placement_allocations(
+            self.context, mock.sentinel.report_client, pci_requests,
+            provider_mapping)
+
+        self.assertEqual(
+            {uuids.rp1, uuids.rp2}, set(req.spec[0]["rp_uuids"].split(','))
+        )
+
     def test_pci_request_has_no_mapping(self):
         pci_requests = [objects.InstancePCIRequest(requester_id=uuids.port_1)]
         provider_mapping = {}
 
-        compute_utils.update_pci_request_spec_with_allocated_interface_name(
+        compute_utils.update_pci_request_with_placement_allocations(
             self.context, mock.sentinel.report_client, pci_requests,
             provider_mapping)
 
     def test_pci_request_ambiguous_mapping(self):
-        pci_requests = [objects.InstancePCIRequest(requester_id=uuids.port_1)]
+        pci_requests = [
+            objects.InstancePCIRequest(
+                requester_id=uuids.port_1, request_id=uuids.req1
+            )
+        ]
         provider_mapping = {uuids.port_1: [uuids.rp1, uuids.rp2]}
 
         self.assertRaises(
             exception.AmbiguousResourceProviderForPCIRequest,
             (compute_utils.
-             update_pci_request_spec_with_allocated_interface_name),
+             update_pci_request_with_placement_allocations),
             self.context, mock.sentinel.report_client, pci_requests,
             provider_mapping)
 
     def test_unexpected_provider_name(self):
         report_client = mock.Mock(spec=report.SchedulerReportClient)
         report_client.get_resource_provider_name.return_value = 'unexpected'
-        pci_requests = [objects.InstancePCIRequest(
-            requester_id=uuids.port_1, spec=[{}])]
+        pci_requests = [
+            objects.InstancePCIRequest(
+                requester_id=uuids.port_1, spec=[{}], request_id=uuids.req1
+            )
+        ]
+
         provider_mapping = {uuids.port_1: [uuids.rp1]}
 
         self.assertRaises(
             exception.UnexpectedResourceProviderNameForPCIRequest,
             (compute_utils.
-             update_pci_request_spec_with_allocated_interface_name),
+             update_pci_request_with_placement_allocations),
             self.context, report_client, pci_requests,
             provider_mapping)
 
@@ -1610,11 +1709,14 @@ class PciRequestUpdateTestCase(test.NoDBTestCase):
         report_client = mock.Mock(spec=report.SchedulerReportClient)
         report_client.get_resource_provider_name.return_value = (
             'host:agent:enp0s31f6')
-        pci_requests = [objects.InstancePCIRequest(
-            requester_id=uuids.port_1, spec=[{}],)]
+        pci_requests = [
+            objects.InstancePCIRequest(
+                requester_id=uuids.port_1, spec=[{}], request_id=uuids.req1
+            )
+        ]
         provider_mapping = {uuids.port_1: [uuids.rp1]}
 
-        compute_utils.update_pci_request_spec_with_allocated_interface_name(
+        compute_utils.update_pci_request_with_placement_allocations(
             self.context, report_client, pci_requests, provider_mapping)
 
         report_client.get_resource_provider_name.assert_called_once_with(
