@@ -12,10 +12,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from oslo_utils.fixture import uuidsentinel
 
-from nova.tests import uuidsentinel
 from nova import utils
 
+
 fake_token = uuidsentinel.token
 fake_token_hash = utils.get_sha256_str(fake_token)
 fake_instance_uuid = uuidsentinel.instance
@@ -26,8 +27,10 @@ fake_token_dict = {
     'token_hash': fake_token_hash,
     'console_type': 'fake-type',
     'host': 'fake-host',
-    'port': 1000,
+    'port': 5900,
+    'tls_port': 5901,
     'internal_access_path': 'fake-path',
     'instance_uuid': fake_instance_uuid,
     'expires': 100,
+    'access_url_base': 'http://fake.url.fake/root.html'
     }
