@@ -17,10 +17,9 @@
 import copy
 import datetime
 import io
+from unittest import mock
 
 import fixtures as fx
-import futurist
-import mock
 from oslo_config import cfg
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
@@ -28,13 +27,14 @@ from oslo_utils.fixture import uuidsentinel as uuids
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 from oslotest import output
-import sqlalchemy
+import sqlalchemy as sa
 import testtools
 
 from nova.compute import rpcapi as compute_rpcapi
 from nova import conductor
 from nova import context
-from nova.db.sqlalchemy import api as session
+from nova.db.api import api as api_db_api
+from nova.db.main import api as main_db_api
 from nova import exception
 from nova.network import neutron as neutron_api
 from nova import objects
@@ -42,7 +42,6 @@ from nova.objects import base as obj_base
 from nova.objects import service as service_obj
 from nova import test
 from nova.tests import fixtures
-from nova.tests.unit import conf_fixture
 from nova.tests.unit import fake_instance
 from nova import utils
 
@@ -51,6 +50,20 @@ CONF = cfg.CONF
 
 class TestLogging(testtools.TestCase):
     def test_default_logging(self):
+        # This test validates that in default logging mode,
+        # we have two logging handlers:
+        # 1 x to display default messages (info, error, warnings...)
+        # 1 x to redirect debug messages to null and so don't display them.
+
+        # However, if OS_DEBUG=True is set in a shell session, then the test is
+        # run and fails. Because, in debug mode, we should have
+        # only one handler to display all messages.
+
+        # Here, we explicitly set OS_DEBUG=0.
+        # So it will ensure we have two handlers whatever
+        # OS_DEBUG value set in the user shell.
+        self.useFixture(fx.EnvironmentVariable('OS_DEBUG', '0'))
+
         stdlog = self.useFixture(fixtures.StandardLogging())
         root = logging.getLogger()
         # there should be a null handler as well at DEBUG
@@ -90,11 +103,12 @@ class TestLogging(testtools.TestCase):
 class TestOSAPIFixture(testtools.TestCase):
     @mock.patch('nova.objects.Service.get_by_host_and_binary')
     @mock.patch('nova.objects.Service.create')
+    @mock.patch('nova.utils.raise_if_old_compute', new=mock.Mock())
     def test_responds_to_version(self, mock_service_create, mock_get):
         """Ensure the OSAPI server responds to calls sensibly."""
         self.useFixture(output.CaptureOutput())
         self.useFixture(fixtures.StandardLogging())
-        self.useFixture(conf_fixture.ConfFixture())
+        self.useFixture(fixtures.ConfFixture())
         self.useFixture(fixtures.RPCFixture('nova.test'))
         api = self.useFixture(fixtures.OSAPIFixture()).api
 
@@ -119,66 +133,71 @@ class TestOSAPIFixture(testtools.TestCase):
 class TestDatabaseFixture(testtools.TestCase):
     def test_fixture_reset(self):
         # because this sets up reasonable db connection strings
-        self.useFixture(conf_fixture.ConfFixture())
-        self.useFixture(fixtures.Database())
-        engine = session.get_engine()
+        self.useFixture(fixtures.ConfFixture())
+        db_fixture = fixtures.Database()
+        self.useFixture(db_fixture)
+        engine = main_db_api.get_engine()
         conn = engine.connect()
-        result = conn.execute("select * from instance_types")
+        result = conn.execute(sa.text("SELECT * FROM instance_types"))
         rows = result.fetchall()
         self.assertEqual(0, len(rows), "Rows %s" % rows)
 
         # insert a 6th instance type, column 5 below is an int id
         # which has a constraint on it, so if new standard instance
         # types are added you have to bump it.
-        conn.execute("insert into instance_types VALUES "
-                     "(NULL, NULL, NULL, 't1.test', 6, 4096, 2, 0, NULL, '87'"
-                     ", 1.0, 40, 0, 0, 1, 0)")
-        result = conn.execute("select * from instance_types")
+        conn.execute(sa.text(
+            "INSERT INTO instance_types VALUES "
+            "(NULL, NULL, NULL, 't1.test', 6, 4096, 2, 0, NULL, '87'"
+            ", 1.0, 40, 0, 0, 1, 0)"
+        ))
+        result = conn.execute(sa.text("SELECT * FROM instance_types"))
         rows = result.fetchall()
         self.assertEqual(1, len(rows), "Rows %s" % rows)
 
-        # reset by invoking the fixture again
-        #
         # NOTE(sdague): it's important to reestablish the db
         # connection because otherwise we have a reference to the old
         # in mem db.
-        self.useFixture(fixtures.Database())
+        db_fixture.reset()
+        engine = main_db_api.get_engine()
         conn = engine.connect()
-        result = conn.execute("select * from instance_types")
+        result = conn.execute(sa.text("SELECT * FROM instance_types"))
         rows = result.fetchall()
         self.assertEqual(0, len(rows), "Rows %s" % rows)
 
     def test_api_fixture_reset(self):
         # This sets up reasonable db connection strings
-        self.useFixture(conf_fixture.ConfFixture())
-        self.useFixture(fixtures.Database(database='api'))
-        engine = session.get_api_engine()
+        self.useFixture(fixtures.ConfFixture())
+        db_fixture = fixtures.Database(database='api')
+        self.useFixture(db_fixture)
+        engine = api_db_api.get_engine()
         conn = engine.connect()
-        result = conn.execute("select * from cell_mappings")
+        result = conn.execute(sa.text("SELECT * FROM cell_mappings"))
         rows = result.fetchall()
         self.assertEqual(0, len(rows), "Rows %s" % rows)
 
         uuid = uuidutils.generate_uuid()
-        conn.execute("insert into cell_mappings (uuid, name) VALUES "
-                     "('%s', 'fake-cell')" % (uuid,))
-        result = conn.execute("select * from cell_mappings")
+        conn.execute(
+            sa.text(
+                "INSERT INTO cell_mappings (uuid, name) VALUES (:uuid, :name)"
+            ).bindparams(uuid=uuid, name='fake-cell'),
+        )
+        result = conn.execute(sa.text("SELECT * FROM cell_mappings"))
         rows = result.fetchall()
         self.assertEqual(1, len(rows), "Rows %s" % rows)
 
-        # reset by invoking the fixture again
-        #
         # NOTE(sdague): it's important to reestablish the db
         # connection because otherwise we have a reference to the old
         # in mem db.
-        self.useFixture(fixtures.Database(database='api'))
+        db_fixture.reset()
+        engine = api_db_api.get_engine()
         conn = engine.connect()
-        result = conn.execute("select * from cell_mappings")
+        result = conn.execute(sa.text("SELECT * FROM cell_mappings"))
         rows = result.fetchall()
         self.assertEqual(0, len(rows), "Rows %s" % rows)
 
     def test_fixture_cleanup(self):
         # because this sets up reasonable db connection strings
-        self.useFixture(conf_fixture.ConfFixture())
+        self.useFixture(fixtures.ConfFixture())
         fix = fixtures.Database()
         self.useFixture(fix)
 
@@ -186,24 +205,27 @@ class TestDatabaseFixture(testtools.TestCase):
         fix.cleanup()
 
         # ensure the db contains nothing
-        engine = session.get_engine()
+        engine = main_db_api.get_engine()
         conn = engine.connect()
         schema = "".join(line for line in conn.connection.iterdump())
         self.assertEqual(schema, "BEGIN TRANSACTION;COMMIT;")
 
     def test_api_fixture_cleanup(self):
         # This sets up reasonable db connection strings
-        self.useFixture(conf_fixture.ConfFixture())
+        self.useFixture(fixtures.ConfFixture())
         fix = fixtures.Database(database='api')
         self.useFixture(fix)
 
         # No data inserted by migrations so we need to add a row
-        engine = session.get_api_engine()
+        engine = api_db_api.get_engine()
         conn = engine.connect()
         uuid = uuidutils.generate_uuid()
-        conn.execute("insert into cell_mappings (uuid, name) VALUES "
-                     "('%s', 'fake-cell')" % (uuid,))
-        result = conn.execute("select * from cell_mappings")
+        conn.execute(
+            sa.text(
+                "INSERT INTO cell_mappings (uuid, name) VALUES (:uuid, :name)"
+            ).bindparams(uuid=uuid, name='fake-cell'),
+        )
+        result = conn.execute(sa.text("SELECT * FROM cell_mappings"))
         rows = result.fetchall()
         self.assertEqual(1, len(rows), "Rows %s" % rows)
 
@@ -211,53 +233,28 @@ class TestDatabaseFixture(testtools.TestCase):
         fix.cleanup()
 
         # Ensure the db contains nothing
-        engine = session.get_api_engine()
+        engine = api_db_api.get_engine()
         conn = engine.connect()
         schema = "".join(line for line in conn.connection.iterdump())
         self.assertEqual("BEGIN TRANSACTION;COMMIT;", schema)
 
-    def test_fixture_schema_version(self):
-        self.useFixture(conf_fixture.ConfFixture())
-
-        # In/after 317 aggregates did have uuid
-        self.useFixture(fixtures.Database(version=318))
-        engine = session.get_engine()
-        engine.connect()
-        meta = sqlalchemy.MetaData(engine)
-        aggregate = sqlalchemy.Table('aggregates', meta, autoload=True)
-        self.assertTrue(hasattr(aggregate.c, 'uuid'))
-
-        # Before 317, aggregates had no uuid
-        self.useFixture(fixtures.Database(version=316))
-        engine = session.get_engine()
-        engine.connect()
-        meta = sqlalchemy.MetaData(engine)
-        aggregate = sqlalchemy.Table('aggregates', meta, autoload=True)
-        self.assertFalse(hasattr(aggregate.c, 'uuid'))
-        engine.dispose()
-
-    def test_fixture_after_database_fixture(self):
-        self.useFixture(conf_fixture.ConfFixture())
-        self.useFixture(fixtures.Database())
-        self.useFixture(fixtures.Database(version=318))
-
 
 class TestDefaultFlavorsFixture(testtools.TestCase):
     @mock.patch("nova.objects.flavor.Flavor._send_notification")
     def test_flavors(self, mock_send_notification):
-        self.useFixture(conf_fixture.ConfFixture())
+        self.useFixture(fixtures.ConfFixture())
         self.useFixture(fixtures.Database())
         self.useFixture(fixtures.Database(database='api'))
 
-        engine = session.get_api_engine()
+        engine = api_db_api.get_engine()
         conn = engine.connect()
-        result = conn.execute("select * from flavors")
+        result = conn.execute(sa.text("SELECT * FROM flavors"))
         rows = result.fetchall()
         self.assertEqual(0, len(rows), "Rows %s" % rows)
 
         self.useFixture(fixtures.DefaultFlavorsFixture())
 
-        result = conn.execute("select * from flavors")
+        result = conn.execute(sa.text("SELECT * FROM flavors"))
         rows = result.fetchall()
         self.assertEqual(6, len(rows), "Rows %s" % rows)
 
@@ -281,73 +278,40 @@ class TestIndirectionAPIFixture(testtools.TestCase):
 
 class TestSpawnIsSynchronousFixture(testtools.TestCase):
     def test_spawn_patch(self):
-        orig_spawn = utils.spawn_n
+        orig_spawn = utils.spawn
 
         fix = fixtures.SpawnIsSynchronousFixture()
         self.useFixture(fix)
-        self.assertNotEqual(orig_spawn, utils.spawn_n)
+        self.assertNotEqual(orig_spawn, utils.spawn)
 
     def test_spawn_passes_through(self):
         self.useFixture(fixtures.SpawnIsSynchronousFixture())
         tester = mock.MagicMock()
-        utils.spawn_n(tester.function, 'foo', bar='bar')
+        utils.spawn(tester.function, 'foo', bar='bar')
         tester.function.assert_called_once_with('foo', bar='bar')
 
-    def test_spawn_return_has_wait(self):
+    def test_spawn_return_has_result(self):
         self.useFixture(fixtures.SpawnIsSynchronousFixture())
-        gt = utils.spawn(lambda x: '%s' % x, 'foo')
-        foo = gt.wait()
+        future = utils.spawn(lambda x: '%s' % x, 'foo')
+        foo = future.result()
         self.assertEqual('foo', foo)
 
-    def test_spawn_n_return_has_wait(self):
+    def test_spawn_callback(self):
         self.useFixture(fixtures.SpawnIsSynchronousFixture())
-        gt = utils.spawn_n(lambda x: '%s' % x, 'foo')
-        foo = gt.wait()
-        self.assertEqual('foo', foo)
-
-    def test_spawn_has_link(self):
-        self.useFixture(fixtures.SpawnIsSynchronousFixture())
-        gt = utils.spawn(mock.MagicMock)
-        passed_arg = 'test'
+        future = utils.spawn(mock.MagicMock)
         call_count = []
 
-        def fake(thread, param):
-            self.assertEqual(gt, thread)
-            self.assertEqual(passed_arg, param)
+        def fake(thread):
+            self.assertEqual(future, thread)
             call_count.append(1)
 
-        gt.link(fake, passed_arg)
+        future.add_done_callback(fake)
         self.assertEqual(1, len(call_count))
 
-    def test_spawn_n_has_link(self):
-        self.useFixture(fixtures.SpawnIsSynchronousFixture())
-        gt = utils.spawn_n(mock.MagicMock)
-        passed_arg = 'test'
-        call_count = []
-
-        def fake(thread, param):
-            self.assertEqual(gt, thread)
-            self.assertEqual(passed_arg, param)
-            call_count.append(1)
-
-        gt.link(fake, passed_arg)
-        self.assertEqual(1, len(call_count))
-
-
-class TestSynchronousThreadPoolExecutorFixture(testtools.TestCase):
-    def test_submit_passes_through(self):
-        self.useFixture(fixtures.SynchronousThreadPoolExecutorFixture())
-        tester = mock.MagicMock()
-        executor = futurist.GreenThreadPoolExecutor()
-        future = executor.submit(tester.function, 'foo', bar='bar')
-        tester.function.assert_called_once_with('foo', bar='bar')
-        result = future.result()
-        self.assertEqual(tester.function.return_value, result)
-
 
 class TestBannedDBSchemaOperations(testtools.TestCase):
     def test_column(self):
-        column = sqlalchemy.Column()
+        column = sa.Column()
         with fixtures.BannedDBSchemaOperations(['Column']):
             self.assertRaises(exception.DBNotAllowed,
                               column.drop)
@@ -355,7 +319,7 @@ class TestBannedDBSchemaOperations(testtools.TestCase):
                               column.alter)
 
     def test_table(self):
-        table = sqlalchemy.Table()
+        table = sa.Table("foo", sa.MetaData())
         with fixtures.BannedDBSchemaOperations(['Table']):
             self.assertRaises(exception.DBNotAllowed,
                               table.drop)
