@@ -32,6 +32,7 @@ import fixtures
 import os_resource_classes as orc
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
+from oslo_utils.fixture import uuidsentinel as uuids
 from oslo_utils import versionutils
 
 from nova.compute import power_state
@@ -48,6 +49,7 @@ from nova.objects import migrate_data
 from nova.virt import driver
 from nova.virt import hardware
 from nova.virt.ironic import driver as ironic
+import nova.virt.node
 from nova.virt import virtapi
 
 CONF = nova.conf.CONF
@@ -117,6 +119,11 @@ class FakeDriver(driver.ComputeDriver):
         "supports_pcpus": False,
         "supports_accelerators": True,
         "supports_remote_managed_ports": True,
+        "supports_address_space_passthrough": True,
+        "supports_address_space_emulated": True,
+        "supports_stateless_firmware": True,
+        "supports_virtio_fs": True,
+        "supports_mem_backing_file": True,
 
         # Supported image types
         "supports_image_type_raw": True,
@@ -160,8 +167,8 @@ class FakeDriver(driver.ComputeDriver):
         self._host = host
         # NOTE(gibi): this is unnecessary complex and fragile but this is
         # how many current functional sample tests expect the node name.
-        self._nodes = (['fake-mini'] if self._host == 'compute'
-                       else [self._host])
+        self._set_nodes(['fake-mini'] if self._host == 'compute'
+                        else [self._host])
 
     def _set_nodes(self, nodes):
         # NOTE(gibi): this is not part of the driver interface but used
@@ -213,7 +220,7 @@ class FakeDriver(driver.ComputeDriver):
 
     def reboot(self, context, instance, network_info, reboot_type,
                block_device_info=None, bad_volumes_callback=None,
-               accel_info=None):
+               accel_info=None, share_info=None):
         # If the guest is not on the hypervisor and we're doing a hard reboot
         # then mimic the libvirt driver by spawning the guest.
         if (instance.uuid not in self.instances and
@@ -234,11 +241,11 @@ class FakeDriver(driver.ComputeDriver):
         pass
 
     def resume_state_on_host_boot(self, context, instance, network_info,
-                                  block_device_info=None):
+                                  share_info, block_device_info=None):
         pass
 
     def rescue(self, context, instance, network_info, image_meta,
-               rescue_password, block_device_info):
+               rescue_password, block_device_info, share_info):
         pass
 
     def unrescue(
@@ -281,12 +288,21 @@ class FakeDriver(driver.ComputeDriver):
             raise exception.InstanceNotFound(instance_id=instance.uuid)
 
     def power_on(self, context, instance, network_info,
-                 block_device_info=None, accel_info=None):
+                 block_device_info=None, accel_info=None, share_info=None):
         if instance.uuid in self.instances:
             self.instances[instance.uuid].state = power_state.RUNNING
+            if share_info:
+                for share in share_info:
+                    share.activate()
         else:
             raise exception.InstanceNotFound(instance_id=instance.uuid)
 
+    def mount_share(self, context, instance, share_mapping):
+        pass
+
+    def umount_share(self, context, instance, share_mapping):
+        pass
+
     def trigger_crash_dump(self, instance):
         pass
 
@@ -305,7 +321,14 @@ class FakeDriver(driver.ComputeDriver):
     def suspend(self, context, instance):
         pass
 
-    def resume(self, context, instance, network_info, block_device_info=None):
+    def resume(
+        self,
+        context,
+        instance,
+        network_info,
+        block_device_info=None,
+        share_info=None
+    ):
         pass
 
     def destroy(self, context, instance, network_info, block_device_info=None,
@@ -453,30 +476,29 @@ class FakeDriver(driver.ComputeDriver):
         return 'FAKE CONSOLE OUTPUT\nANOTHER\nLAST LINE'
 
     def get_vnc_console(self, context, instance):
-        return ctype.ConsoleVNC(internal_access_path='FAKE',
-                                host='fakevncconsole.com',
-                                port=6969)
+        return ctype.ConsoleVNC(
+            internal_access_path=uuids.vnc_access_path,
+            host='fakevncconsole.com',
+            port=6969)
 
     def get_spice_console(self, context, instance):
-        return ctype.ConsoleSpice(internal_access_path='FAKE',
-                                  host='fakespiceconsole.com',
-                                  port=6969,
-                                  tlsPort=6970)
-
-    def get_rdp_console(self, context, instance):
-        return ctype.ConsoleRDP(internal_access_path='FAKE',
-                                host='fakerdpconsole.com',
-                                port=6969)
+        return ctype.ConsoleSpice(
+            internal_access_path=uuids.spice_access_path,
+            host='fakespiceconsole.com',
+            port=6969,
+            tlsPort=6970)
 
     def get_serial_console(self, context, instance):
-        return ctype.ConsoleSerial(internal_access_path='FAKE',
-                                   host='fakerdpconsole.com',
-                                   port=6969)
+        return ctype.ConsoleSerial(
+            internal_access_path=uuids.serial_access_path,
+            host='fakerdpconsole.com',
+            port=6969)
 
     def get_mks_console(self, context, instance):
-        return ctype.ConsoleMKS(internal_access_path='FAKE',
-                                host='fakemksconsole.com',
-                                port=6969)
+        return ctype.ConsoleMKS(
+            internal_access_path=uuids.mks_access_path,
+            host='fakemksconsole.com',
+            port=6969)
 
     def get_available_resource(self, nodename):
         """Updates compute manager resource info on ComputeNode table.
@@ -504,6 +526,12 @@ class FakeDriver(driver.ComputeDriver):
         host_status['host_hostname'] = nodename
         host_status['host_name_label'] = nodename
         host_status['cpu_info'] = jsonutils.dumps(cpu_info)
+        # NOTE(danms): Because the fake driver runs on the same host
+        # in tests, potentially with multiple nodes, we need to
+        # control our node uuids. Make sure we return a unique and
+        # consistent uuid for each node we are responsible for to
+        # avoid the persistent local node identity from taking over.
+        host_status['uuid'] = str(getattr(uuids, 'node_%s' % nodename))
         return host_status
 
     def update_provider_tree(self, provider_tree, nodename, allocations=None):
@@ -592,7 +620,7 @@ class FakeDriver(driver.ComputeDriver):
                          allocations, block_device_info=None, power_on=True):
         injected_files = admin_password = None
         # Finish migration is just like spawning the guest on a destination
-        # host during resize/cold migrate, so re-use the spawn() fake to
+        # host during resize/cold migrate, so reuse the spawn() fake to
         # claim resources and track the instance on this "hypervisor".
         self.spawn(context, instance, image_meta, injected_files,
                    admin_password, allocations,
@@ -646,6 +674,10 @@ class FakeDriver(driver.ComputeDriver):
     def get_available_nodes(self, refresh=False):
         return self._nodes
 
+    def get_nodenames_by_uuid(self, refresh=False):
+        return {str(getattr(uuids, 'node_%s' % n)): n
+                for n in self.get_available_nodes()}
+
     def instance_on_disk(self, instance):
         return False
 
@@ -764,7 +796,7 @@ class PredictableNodeUUIDDriver(SmallFakeDriver):
             PredictableNodeUUIDDriver, self).get_available_resource(nodename)
         # This is used in ComputeNode.update_from_virt_driver which is called
         # from the ResourceTracker when creating a ComputeNode.
-        resources['uuid'] = uuid.uuid5(uuid.NAMESPACE_DNS, nodename)
+        resources['uuid'] = str(uuid.uuid5(uuid.NAMESPACE_DNS, nodename))
         return resources
 
 
@@ -1119,3 +1151,22 @@ class EphEncryptionDriverPLAIN(MediumFakeDriver):
         FakeDriver.capabilities,
         supports_ephemeral_encryption=True,
         supports_ephemeral_encryption_plain=True)
+
+
+class FakeDriverWithoutFakeNodes(FakeDriver):
+    """FakeDriver that behaves like a real single-node driver.
+
+    This behaves like a real virt driver from the perspective of its
+    nodes, with a stable nodename and use of the global node identity
+    stuff to provide a stable node UUID.
+    """
+
+    def get_available_resource(self, nodename):
+        resources = super().get_available_resource(nodename)
+        resources['uuid'] = nova.virt.node.get_local_node_uuid()
+        return resources
+
+    def get_nodenames_by_uuid(self, refresh=False):
+        return {
+            nova.virt.node.get_local_node_uuid(): self.get_available_nodes()[0]
+        }
